/* GTK NAMED COLORS
   ----------------
   use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color #eff0f1;
/*
text color for entries, views and content in general */
@define-color theme_text_color #eff0f1;
/*
widget base background color */
@define-color theme_bg_color #31363b;
/*
text widgets and the like base background color */
@define-color theme_base_color #232629;
/*
base background color of selections */
@define-color theme_selected_bg_color #3daee9;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color #eff0f1;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #2d3136;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color rgba(216, 218, 221, 0.35);
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color rgba(216, 218, 221, 0.35);
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #eff0f1;
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color #eff0f1;
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #31363b;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #232629;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color rgba(61, 174, 233, 0.5);
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #eff0f1;
/*
widgets main borders color */
@define-color borders #616569;
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders #616569;
/*
widgets main borders color insensitive */
@define-color insensitive_borders rgba(88, 92, 95, 0.35);
/*
these are pretty self explicative */
@define-color warning_color #f67400;
@define-color error_color #da4453;
@define-color success_color #27ae60;
@define-color content_view_bg #232629;
* {
  padding: 0;
  -GtkToolButton-icon-spacing: 4;
  -GtkTextView-error-underline-color: #da4453;
  -GtkButton-child-displacement-x: 0;
  -GtkButton-child-displacement-y: 0;
  -GtkCheckButton-indicator-size: 18;
  -GtkCheckMenuItem-indicator-size: 18;
  -GtkScrolledWindow-scrollbar-spacing: 0;
  -GtkScrolledWindow-scrollbars-within-bevel: 0;
  -GtkScrolled-window-overlay-scrolling: FALSE;
  -GtkToolItemGroup-expander-size: 11;
  -GtkExpander-expander-size: 16;
  -GtkTreeView-expander-size: 11;
  -GtkTreeView-horizontal-separator: 4;
  -GtkWidget-text-handle-width: 20;
  -GtkWidget-text-handle-height: 20;
  -GtkDialog-button-spacing: 4;
  -GtkDialog-action-area-border: 0;
  -GtkStatusbar-shadow-type: none;
  outline-width: 0px; }

/***************
 * Base States *
 ***************/
.background {
  color: #eff0f1;
  background-color: #31363b; }
  .background:backdrop {
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #eff0f1;
    background-color: #31363b; }

/*
   These wildcard seems unavoidable, need to investigate.
   Wildcards are bad and troublesome, use them with care,
   or better, just don't.
   Everytime a wildcard is used a kitten dies, painfully.
*/
*:disabled {
  -gtk-icon-effect: dim; }

.gtkstyle-fallback {
  background-color: #31363b;
  color: #eff0f1; }
  .gtkstyle-fallback:hover {
    background-color: #485057;
    color: #eff0f1; }
  .gtkstyle-fallback:active {
    background-color: #1a1d1f;
    color: #eff0f1; }
  .gtkstyle-fallback:disabled {
    background-color: #2d3136;
    color: rgba(216, 218, 221, 0.35); }
  .gtkstyle-fallback:selected {
    background-color: #3daee9;
    color: #eff0f1; }

.view text,
textview text,
.view {
  color: #eff0f1;
  background-color: #232629; }
  .view text:backdrop,
  textview text:backdrop,
  .view:backdrop {
    color: #eff0f1;
    background-color: #232629; }
  .view text:selected:focus,
  textview text:selected:focus, .view text:selected,
  textview text:selected,
  .view:selected:focus,
  .view:selected {
    border-radius: 3px; }

textview border {
  background-color: #232629;
  background-image: image(#616569);
  background-repeat: no-repeat; }
  textview border:backdrop {
    background-color: #232629; }
  textview border.bottom {
    background-size: 100% 1px;
    background-position: top; }
  textview border.top {
    background-size: 100% 1px;
    background-position: bottom; }
  textview border.left {
    background-size: 1px 100%;
    background-position: right; }
  textview border.right {
    background-size: 1px 100%;
    background-position: left; }

.rubberband,
rubberband,
flowbox rubberband,
treeview.view rubberband {
  border: 1px solid #3daee9;
  background-color: rgba(61, 174, 233, 0.2); }
  .rubberband:backdrop,
  rubberband:backdrop,
  treeview.view rubberband:backdrop {
    border-color: #3daee9;
    background-color: rgba(61, 174, 233, 0.2); }

flowbox flowboxchild {
  padding: 3px;
  border-radius: 3px; }
  flowbox flowboxchild:selected {
    outline-offset: 0px; }

label.separator {
  color: #eff0f1; }
  label.separator:backdrop {
    color: #eff0f1; }
label selection {
  background-color: #3daee9;
  color: #eff0f1; }
label:disabled {
  color: rgba(216, 218, 221, 0.35); }
  label:disabled:backdrop {
    color: rgba(216, 218, 221, 0.35); }
label:backdrop {
  color: #eff0f1; }

.dim-label, label.separator,
headerbar .subtitle {
  opacity: 0.5;
  text-shadow: none; }

assistant .sidebar {
  background-color: #eff0f1;
  border-top: 1px solid #616569; }
  assistant .sidebar:backdrop {
    background-color: #eff0f1;
    border-color: #616569; }
assistant.csd .sidebar {
  border-top-style: none; }
assistant .sidebar label {
  padding: 6px 12px; }
assistant .sidebar label.highlight {
  background-color: #4c4e51; }

.app-notification,
.app-notification.frame, .csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier, .csd popover.background.osd, popover.background.osd,
.osd {
  color: #eff0f1;
  border: 1px solid #616569;
  background-color: rgba(49, 54, 59, 0.8);
  background-clip: padding-box;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none; }
  .app-notification:backdrop, popover.background.touch-selection:backdrop, popover.background.magnifier:backdrop, popover.background.osd:backdrop,
  .osd:backdrop {
    color: #eff0f1;
    background-color: rgba(49, 54, 59, 0.8);
    -gtk-icon-shadow: none; }

.view text:selected:focus,
textview text:selected:focus, .view text:selected,
textview text:selected,
.view:selected:focus,
.view:selected, .view text selection:focus, .view text selection,
textview text selection:focus,
textview text selection, flowbox flowboxchild:selected, spinbutton:not(.vertical) selection:focus, spinbutton:not(.vertical) selection,
entry selection:focus,
entry selection, row:selected, .sidebar:selected {
  background-color: #3daee9;
  color: #eff0f1; }
  textview text:hover:selected:focus, .view text:hover:selected,
  textview text:hover:selected,
  .view:hover:selected, .view text selection:hover,
  textview text selection:hover, flowbox flowboxchild:hover:selected, spinbutton:not(.vertical) selection:hover,
  entry selection:hover, row:hover:selected, .sidebar:hover:selected {
    background-color: #3daee9;
    color: #eff0f1; }
  textview text:backdrop:selected:focus, .view text:backdrop:selected,
  textview text:backdrop:selected,
  .view:backdrop:selected, .view text selection:backdrop,
  textview text selection:backdrop, flowbox flowboxchild:backdrop:selected, label:backdrop selction, spinbutton:not(.vertical) selection:backdrop,
  entry selection:backdrop, row:backdrop:selected, .sidebar:backdrop:selected {
    background-color: rgba(61, 174, 233, 0.5);
    color: #232629; }

.view text:selected:focus,
textview text:selected:focus, .view text:selected,
textview text:selected,
.view:selected:focus,
.view:selected, .view text selection:focus, .view text selection,
textview text selection:focus,
textview text selection, flowbox flowboxchild:selected, spinbutton:not(.vertical) selection:focus, spinbutton:not(.vertical) selection,
entry selection:focus,
entry selection, row:selected, .sidebar:selected {
  background-color: #3daee9;
  border-radius: 0px; }
  .view text:selected:focus,
  textview text:selected:focus, .view text:selected,
  textview text:selected,
  .view:selected:focus,
  .view:selected, .view text selection:focus, .view text selection,
  textview text selection:focus,
  textview text selection, flowbox flowboxchild:selected, spinbutton:not(.vertical) selection:focus, spinbutton:not(.vertical) selection,
  entry selection:focus,
  entry selection, row:selected, .sidebar:selected {
    color: #eff0f1; }
    textview text:disabled:selected:focus, .view text:disabled:selected,
    textview text:disabled:selected,
    .view:disabled:selected, .view text selection:disabled,
    textview text selection:disabled, flowbox flowboxchild:disabled:selected, label:disabled selection, spinbutton:not(.vertical) selection:disabled,
    entry selection:disabled, row:disabled:selected, .sidebar:disabled:selected {
      color: rgba(216, 218, 221, 0.35); }
    textview text:backdrop:selected:focus, .view text:backdrop:selected,
    textview text:backdrop:selected,
    .view:backdrop:selected, .view text selection:backdrop,
    textview text selection:backdrop, flowbox flowboxchild:backdrop:selected, label:backdrop selction, spinbutton:not(.vertical) selection:backdrop,
    entry selection:backdrop, row:backdrop:selected, .sidebar:backdrop:selected {
      color: #eff0f1; }
      .view text:backdrop:disabled:selected,
      textview text:backdrop:disabled:selected,
      .view:backdrop:disabled:selected, .view text selection:backdrop:disabled,
      textview text selection:backdrop:disabled, flowbox flowboxchild:backdrop:disabled:selected, label:disabled selection:backdrop, label:backdrop selction:disabled, spinbutton:not(.vertical) selection:backdrop:disabled,
      entry selection:backdrop:disabled, row:backdrop:disabled:selected, .sidebar:backdrop:disabled:selected {
        color: rgba(216, 218, 221, 0.35); }

/***********
 * Buttons *
 ***********/
@keyframes needs_attention {
  from {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.01, to(#3daee9), to(transparent)); }
  to {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#3daee9), to(transparent)); } }
notebook > header > tabs > arrow, .csd popover.background.touch-selection button, .csd popover.background.magnifier button, popover.background.touch-selection button, popover.background.magnifier button,
button, notebook > header > tabs > arrow.osd,
button.osd {
  border: 1px solid;
  border-radius: 3px;
  padding: 4px 6px;
  background-clip: border-box;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.1);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #eff0f1;
  border-color: #616569;
  background-image: linear-gradient(to bottom, #31373c, #303439); }
  notebook > header > tabs > arrow, button.sidebar-button, popover.background.touch-selection button.flat, popover.background.magnifier button.flat,
  button.flat, notebook > header > tabs > arrow.osd, button.osd.sidebar-button {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    transition: none; }
    notebook > header > tabs > arrow:hover, button.sidebar-button:hover, popover.background.touch-selection button.flat:hover, popover.background.magnifier button.flat:hover,
    button.flat:hover, notebook > header > tabs > arrow.osd:hover {
      transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
      transition-duration: 500ms; }
      notebook > header > tabs > arrow:hover:active, button.sidebar-button:hover:active,
      button.flat:hover:active {
        transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }
    notebook > header > tabs > arrow:checked, button.sidebar-button:checked, popover.background.touch-selection button.flat:checked, popover.background.magnifier button.flat:checked,
    button.flat:checked, notebook > header > tabs > arrow.osd:checked {
      background-color: #616569; }
  notebook > header > tabs > arrow:hover, popover.background.touch-selection button:hover, popover.background.magnifier button:hover,
  button:hover, notebook > header > tabs > arrow.osd:hover {
    color: #eff0f1;
    border-color: #3daee9;
    -gtk-icon-effect: none; }
  notebook > header > tabs > arrow:active, popover.background.touch-selection button:active, popover.background.magnifier button:active,
  button:active, notebook > header > tabs > arrow.osd:active, notebook > header > tabs > arrow:checked, popover.background.touch-selection button:checked, popover.background.magnifier button:checked,
  button:checked, notebook > header > tabs > arrow.osd:checked {
    color: #eff0f1;
    border-color: #3daee9;
    background-image: linear-gradient(to bottom, #45b1ea, #25a4e6);
    transition-duration: 50ms; }
    notebook > header > tabs > arrow:active:hover, popover.background.touch-selection button:active:hover, popover.background.magnifier button:active:hover,
    button:active:hover, notebook > header > tabs > arrow:checked:hover, popover.background.touch-selection button:checked:hover, popover.background.magnifier button:checked:hover,
    button:checked:hover {
      color: #eff0f1;
      border-color: #3daee9;
      background-image: linear-gradient(to bottom, #45b1ea, #25a4e6); }
  notebook > header > tabs > arrow:backdrop, popover.background.touch-selection button:backdrop, popover.background.magnifier button:backdrop,
  button:backdrop, notebook > header > tabs > arrow.osd:backdrop {
    color: #eff0f1;
    border-color: #616569;
    background-image: linear-gradient(to bottom, #31373c, #303439);
    -gtk-icon-effect: none; }
    notebook > header > tabs > arrow:backdrop:active, popover.background.touch-selection button:backdrop:active, popover.background.magnifier button:backdrop:active,
    button:backdrop:active, notebook > header > tabs > arrow:backdrop:checked, popover.background.touch-selection button:backdrop:checked, popover.background.magnifier button:backdrop:checked,
    button:backdrop:checked {
      color: #eff0f1;
      border-color: #3daee9;
      background-image: linear-gradient(to bottom, #45b1ea, #25a4e6); }
    notebook > header > tabs > arrow:backdrop:disabled, popover.background.touch-selection button:backdrop:disabled, popover.background.magnifier button:backdrop:disabled,
    button:backdrop:disabled {
      color: rgba(216, 218, 221, 0.35);
      border-color: rgba(88, 92, 95, 0.35);
      background-image: linear-gradient(to bottom, #2d3236, #2b3034); }
      notebook > header > tabs > arrow:backdrop:disabled > .label, popover.background.touch-selection button:backdrop:disabled > .label, popover.background.magnifier button:backdrop:disabled > .label,
      button:backdrop:disabled > .label {
        color: inherit; }
    notebook > header > tabs > arrow:backdrop:disabled:active,
    button:backdrop:disabled:active, notebook > header > tabs > arrow:backdrop:disabled:checked,
    button:backdrop:disabled:checked {
      color: rgba(216, 218, 221, 0.35);
      border-color: rgba(37, 164, 230, 0.35);
      background-image: linear-gradient(to bottom, rgba(44, 167, 231, 0.35), rgba(25, 152, 218, 0.35)); }
      notebook > header > tabs > arrow:backdrop:disabled:active > .label, popover.background.touch-selection button:backdrop:disabled:active > .label, popover.background.magnifier button:backdrop:disabled:active > .label,
      button:backdrop:disabled:active > .label, notebook > header > tabs > arrow:backdrop:disabled:checked > .label, popover.background.touch-selection button:backdrop:disabled:checked > .label, popover.background.magnifier button:backdrop:disabled:checked > .label,
      button:backdrop:disabled:checked > .label {
        color: inherit; }
  notebook > header > tabs > arrow:backdrop, button.sidebar-button:backdrop, popover.background.touch-selection button.flat:backdrop, popover.background.magnifier button.flat:backdrop,
  button.flat:backdrop, notebook > header > tabs > arrow.osd:backdrop {
    -gtk-icon-effect: none;
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #eff0f1; }
  notebook > header > tabs > arrow:disabled, button.sidebar-button:disabled, popover.background.touch-selection button.flat:disabled, popover.background.magnifier button.flat:disabled,
  button.flat:disabled, notebook > header > tabs > arrow.osd:disabled {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: rgba(216, 218, 221, 0.35); }
  notebook > header > tabs > arrow:backdrop:disabled, button.sidebar-button:backdrop:disabled,
  button.flat:backdrop:disabled {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: rgba(216, 218, 221, 0.35); }
  notebook > header > tabs > arrow:disabled, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled,
  button:disabled, notebook > header > tabs > arrow.osd:disabled {
    color: rgba(216, 218, 221, 0.35);
    border-color: rgba(88, 92, 95, 0.35);
    background-image: linear-gradient(to bottom, #2d3236, #2b3034); }
    notebook > header > tabs > arrow:disabled > .label, popover.background.touch-selection button:disabled > .label, popover.background.magnifier button:disabled > .label,
    button:disabled > .label {
      color: inherit; }
    notebook > header > tabs > arrow:disabled:active, popover.background.touch-selection button:disabled:active, popover.background.magnifier button:disabled:active,
    button:disabled:active, notebook > header > tabs > arrow:disabled:checked, popover.background.touch-selection button:disabled:checked, popover.background.magnifier button:disabled:checked,
    button:disabled:checked {
      color: rgba(216, 218, 221, 0.35);
      border-color: rgba(37, 164, 230, 0.35);
      background-image: linear-gradient(to bottom, rgba(44, 167, 231, 0.35), rgba(25, 152, 218, 0.35)); }
      notebook > header > tabs > arrow:disabled:active > .label, popover.background.touch-selection button:disabled:active > .label, popover.background.magnifier button:disabled:active > .label,
      button:disabled:active > .label, notebook > header > tabs > arrow:disabled:checked > .label, popover.background.touch-selection button:disabled:checked > .label, popover.background.magnifier button:disabled:checked > .label,
      button:disabled:checked > .label {
        color: inherit; }
  notebook > header > tabs > arrow separator, .csd popover.background.touch-selection button separator, .csd popover.background.magnifier button separator, popover.background.touch-selection button separator, popover.background.magnifier button separator,
  button separator, notebook > header > tabs > arrow.osd separator,
  button.osd separator {
    background-color: transparent;
    background-image: none;
    color: transparent; }

notebook > header > tabs > arrow.image-button, popover.background.touch-selection button.image-button, popover.background.magnifier button.image-button,
button.image-button {
  min-width: 16px;
  padding: 6px; }
notebook > header > tabs > arrow.text-button, popover.background.touch-selection button.text-button, popover.background.magnifier button.text-button,
button.text-button {
  padding-left: 6px;
  padding-right: 6px; }
notebook > header > tabs > arrow.text-button.image-button, popover.background.touch-selection button.text-button.image-button, popover.background.magnifier button.text-button.image-button,
button.text-button.image-button {
  padding-left: 6px;
  padding-right: 6px; }
  notebook > header > tabs > arrow.text-button.image-button label, popover.background.touch-selection button.text-button.image-button label, popover.background.magnifier button.text-button.image-button label,
  button.text-button.image-button label {
    padding-left: 6px;
    padding-right: 6px; }
row:selected popover.background.touch-selection button, popover.background.touch-selection row:selected button, row:selected popover.background.magnifier button, popover.background.magnifier row:selected button, row:selected
button {
  border-color: #3daee9; }
  row:selected popover.background.touch-selection button.flat:not(:active):not(:checked):not(:hover):not(disabled), popover.background.touch-selection row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled), row:selected popover.background.magnifier button.flat:not(:active):not(:checked):not(:hover):not(disabled), popover.background.magnifier row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled), row:selected
  button.flat:not(:active):not(:checked):not(:hover):not(disabled) {
    color: #eff0f1;
    border-color: transparent; }
    row:selected popover.background.touch-selection button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, popover.background.touch-selection row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, row:selected popover.background.magnifier button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, popover.background.magnifier row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, row:selected
    button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop {
      color: #eff0f1; }
popover.background.touch-selection button.suggested-action, popover.background.magnifier button.suggested-action, popover.background.touch-selection button.suggested-action.osd button, popover.background.magnifier button.suggested-action.osd button,
button.suggested-action,
button.suggested-action.osd popover.background.touch-selection button,
popover.background.touch-selection button.suggested-action.osd button,
button.suggested-action.osd popover.background.magnifier button,
popover.background.magnifier button.suggested-action.osd button, popover.background.touch-selection button.suggested-action.osd
button, popover.background.magnifier button.suggested-action.osd
button,
button.suggested-action.osd
button {
  box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.1);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #eff0f1;
  border-color: #3daee9;
  background-image: linear-gradient(to bottom, #40afe9, #35abe8); }
  popover.background.touch-selection button.suggested-action.flat, popover.background.magnifier button.suggested-action.flat, popover.background.touch-selection button.suggested-action.osd button.flat, popover.background.magnifier button.suggested-action.osd button.flat,
  button.suggested-action.flat,
  button.suggested-action.osd popover.background.touch-selection button.flat,
  popover.background.touch-selection button.suggested-action.osd button.flat,
  button.suggested-action.osd popover.background.magnifier button.flat,
  popover.background.magnifier button.suggested-action.osd button.flat, popover.background.touch-selection button.suggested-action.osd
  button.flat, popover.background.magnifier button.suggested-action.osd
  button.flat,
  button.suggested-action.osd
  button.flat {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #3daee9; }
  popover.background.touch-selection button.suggested-action:hover, popover.background.magnifier button.suggested-action:hover, popover.background.touch-selection button.suggested-action.osd button:hover, popover.background.magnifier button.suggested-action.osd button:hover,
  button.suggested-action:hover,
  button.suggested-action.osd popover.background.touch-selection button:hover,
  popover.background.touch-selection button.suggested-action.osd button:hover,
  button.suggested-action.osd popover.background.magnifier button:hover,
  popover.background.magnifier button.suggested-action.osd button:hover, popover.background.touch-selection button.suggested-action.osd
  button:hover, popover.background.magnifier button.suggested-action.osd
  button:hover,
  button.suggested-action.osd
  button:hover {
    color: white;
    border-color: #3daee9; }
  popover.background.touch-selection button.suggested-action:active, popover.background.magnifier button.suggested-action:active, popover.background.touch-selection button.suggested-action:checked, popover.background.magnifier button.suggested-action:checked, popover.background.touch-selection button.suggested-action.osd button:active, popover.background.magnifier button.suggested-action.osd button:active, popover.background.touch-selection button.suggested-action.osd button:checked, popover.background.magnifier button.suggested-action.osd button:checked,
  button.suggested-action:active,
  button.suggested-action:checked,
  button.suggested-action.osd popover.background.touch-selection button:active,
  popover.background.touch-selection button.suggested-action.osd button:active,
  button.suggested-action.osd popover.background.magnifier button:active,
  popover.background.magnifier button.suggested-action.osd button:active,
  button.suggested-action.osd popover.background.touch-selection button:checked,
  popover.background.touch-selection button.suggested-action.osd button:checked,
  button.suggested-action.osd popover.background.magnifier button:checked,
  popover.background.magnifier button.suggested-action.osd button:checked, popover.background.touch-selection button.suggested-action.osd
  button:active, popover.background.magnifier button.suggested-action.osd
  button:active, popover.background.touch-selection button.suggested-action.osd
  button:checked, popover.background.magnifier button.suggested-action.osd
  button:checked,
  button.suggested-action.osd
  button:active,
  button.suggested-action.osd
  button:checked {
    color: white;
    border-color: #3daee9;
    background-image: linear-gradient(to bottom, #45b1ea, #25a4e6); }
  popover.background.touch-selection button.suggested-action:backdrop, popover.background.magnifier button.suggested-action:backdrop, popover.background.touch-selection button.suggested-action.flat:backdrop, popover.background.magnifier button.suggested-action.flat:backdrop, popover.background.touch-selection button.suggested-action.osd button:backdrop, popover.background.magnifier button.suggested-action.osd button:backdrop, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop, popover.background.magnifier button.suggested-action.osd button.flat:backdrop,
  button.suggested-action:backdrop,
  button.suggested-action.flat:backdrop,
  button.suggested-action.osd popover.background.touch-selection button:backdrop,
  popover.background.touch-selection button.suggested-action.osd button:backdrop,
  button.suggested-action.osd popover.background.magnifier button:backdrop,
  popover.background.magnifier button.suggested-action.osd button:backdrop,
  button.suggested-action.osd popover.background.touch-selection button.flat:backdrop,
  popover.background.touch-selection button.suggested-action.osd button.flat:backdrop,
  button.suggested-action.osd popover.background.magnifier button.flat:backdrop,
  popover.background.magnifier button.suggested-action.osd button.flat:backdrop, popover.background.touch-selection button.suggested-action.osd
  button:backdrop, popover.background.magnifier button.suggested-action.osd
  button:backdrop, popover.background.touch-selection button.suggested-action.osd
  button.flat:backdrop, popover.background.magnifier button.suggested-action.osd
  button.flat:backdrop,
  button.suggested-action.osd
  button:backdrop,
  button.suggested-action.osd
  button.flat:backdrop {
    color: white;
    border-color: #616569;
    background-image: linear-gradient(to bottom, #40afe9, #35abe8); }
    popover.background.touch-selection button.suggested-action:backdrop:active, popover.background.magnifier button.suggested-action:backdrop:active, popover.background.touch-selection button.suggested-action:backdrop:checked, popover.background.magnifier button.suggested-action:backdrop:checked, popover.background.touch-selection button.suggested-action.flat:backdrop:active, popover.background.magnifier button.suggested-action.flat:backdrop:active, popover.background.touch-selection button.suggested-action.flat:backdrop:checked, popover.background.magnifier button.suggested-action.flat:backdrop:checked, popover.background.touch-selection button.suggested-action.osd button:backdrop:active, popover.background.magnifier button.suggested-action.osd button:backdrop:active, popover.background.touch-selection button.suggested-action.osd button:backdrop:checked, popover.background.magnifier button.suggested-action.osd button:backdrop:checked, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:active, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:active, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:checked, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:checked,
    button.suggested-action:backdrop:active,
    button.suggested-action:backdrop:checked,
    button.suggested-action.flat:backdrop:active,
    button.suggested-action.flat:backdrop:checked,
    button.suggested-action.osd popover.background.touch-selection button:backdrop:active,
    popover.background.touch-selection button.suggested-action.osd button:backdrop:active,
    button.suggested-action.osd popover.background.magnifier button:backdrop:active,
    popover.background.magnifier button.suggested-action.osd button:backdrop:active,
    button.suggested-action.osd popover.background.touch-selection button:backdrop:checked,
    popover.background.touch-selection button.suggested-action.osd button:backdrop:checked,
    button.suggested-action.osd popover.background.magnifier button:backdrop:checked,
    popover.background.magnifier button.suggested-action.osd button:backdrop:checked,
    button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:active,
    popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:active,
    button.suggested-action.osd popover.background.magnifier button.flat:backdrop:active,
    popover.background.magnifier button.suggested-action.osd button.flat:backdrop:active,
    button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:checked,
    popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:checked,
    button.suggested-action.osd popover.background.magnifier button.flat:backdrop:checked,
    popover.background.magnifier button.suggested-action.osd button.flat:backdrop:checked, popover.background.touch-selection button.suggested-action.osd
    button:backdrop:active, popover.background.magnifier button.suggested-action.osd
    button:backdrop:active, popover.background.touch-selection button.suggested-action.osd
    button:backdrop:checked, popover.background.magnifier button.suggested-action.osd
    button:backdrop:checked, popover.background.touch-selection button.suggested-action.osd
    button.flat:backdrop:active, popover.background.magnifier button.suggested-action.osd
    button.flat:backdrop:active, popover.background.touch-selection button.suggested-action.osd
    button.flat:backdrop:checked, popover.background.magnifier button.suggested-action.osd
    button.flat:backdrop:checked,
    button.suggested-action.osd
    button:backdrop:active,
    button.suggested-action.osd
    button:backdrop:checked,
    button.suggested-action.osd
    button.flat:backdrop:active,
    button.suggested-action.osd
    button.flat:backdrop:checked {
      color: white;
      border-color: #3daee9;
      background-image: linear-gradient(to bottom, #45b1ea, #25a4e6); }
    popover.background.touch-selection button.suggested-action:backdrop:disabled, popover.background.magnifier button.suggested-action:backdrop:disabled, popover.background.touch-selection button.suggested-action.flat:backdrop:disabled, popover.background.magnifier button.suggested-action.flat:backdrop:disabled, popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled, popover.background.magnifier button.suggested-action.osd button:backdrop:disabled, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled,
    button.suggested-action:backdrop:disabled,
    button.suggested-action.flat:backdrop:disabled,
    button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled,
    popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled,
    button.suggested-action.osd popover.background.magnifier button:backdrop:disabled,
    popover.background.magnifier button.suggested-action.osd button:backdrop:disabled,
    button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled,
    popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled,
    button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled,
    popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled, popover.background.touch-selection button.suggested-action.osd
    button:backdrop:disabled, popover.background.magnifier button.suggested-action.osd
    button:backdrop:disabled, popover.background.touch-selection button.suggested-action.osd
    button.flat:backdrop:disabled, popover.background.magnifier button.suggested-action.osd
    button.flat:backdrop:disabled,
    button.suggested-action.osd
    button:backdrop:disabled,
    button.suggested-action.osd
    button.flat:backdrop:disabled {
      color: rgba(216, 218, 221, 0.35);
      border-color: rgba(88, 92, 95, 0.35);
      background-image: linear-gradient(to bottom, #2d3236, #2b3034); }
      popover.background.touch-selection button.suggested-action:backdrop:disabled > .label, popover.background.magnifier button.suggested-action:backdrop:disabled > .label, popover.background.touch-selection button.suggested-action.flat:backdrop:disabled > .label, popover.background.magnifier button.suggested-action.flat:backdrop:disabled > .label, popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button:backdrop:disabled > .label, popover.background.magnifier button.suggested-action.osd button:backdrop:disabled > .label, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled > .label, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled > .label,
      button.suggested-action:backdrop:disabled > .label,
      button.suggested-action.flat:backdrop:disabled > .label,
      button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled > .label,
      popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled > .label,
      button.suggested-action.osd popover.background.magnifier button:backdrop:disabled > .label,
      popover.background.magnifier button.suggested-action.osd button:backdrop:disabled > .label,
      button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled > .label,
      popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled > .label,
      button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled > .label,
      popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled > .label, popover.background.touch-selection button.suggested-action.osd
      button:backdrop:disabled > .label, popover.background.magnifier button.suggested-action.osd
      button:backdrop:disabled > .label, popover.background.touch-selection button.suggested-action.osd
      button.flat:backdrop:disabled > .label, popover.background.magnifier button.suggested-action.osd
      button.flat:backdrop:disabled > .label,
      button.suggested-action.osd
      button:backdrop:disabled > .label,
      button.suggested-action.osd
      button.flat:backdrop:disabled > .label {
        color: inherit; }
      popover.background.touch-selection button.suggested-action:backdrop:disabled:active, popover.background.magnifier button.suggested-action:backdrop:disabled:active, popover.background.touch-selection button.suggested-action:backdrop:disabled:checked, popover.background.magnifier button.suggested-action:backdrop:disabled:checked, popover.background.touch-selection button.suggested-action.flat:backdrop:disabled:active, popover.background.magnifier button.suggested-action.flat:backdrop:disabled:active, popover.background.touch-selection button.suggested-action.flat:backdrop:disabled:checked, popover.background.magnifier button.suggested-action.flat:backdrop:disabled:checked, popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled:active, popover.background.magnifier button.suggested-action.osd button:backdrop:disabled:active, popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled:checked, popover.background.magnifier button.suggested-action.osd button:backdrop:disabled:checked, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled:active, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled:active, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled:checked, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled:checked,
      button.suggested-action:backdrop:disabled:active,
      button.suggested-action:backdrop:disabled:checked,
      button.suggested-action.flat:backdrop:disabled:active,
      button.suggested-action.flat:backdrop:disabled:checked,
      button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled:active,
      popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled:active,
      button.suggested-action.osd popover.background.magnifier button:backdrop:disabled:active,
      popover.background.magnifier button.suggested-action.osd button:backdrop:disabled:active,
      button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled:checked,
      popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled:checked,
      button.suggested-action.osd popover.background.magnifier button:backdrop:disabled:checked,
      popover.background.magnifier button.suggested-action.osd button:backdrop:disabled:checked,
      button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled:active,
      popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled:active,
      button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled:active,
      popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled:active,
      button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled:checked,
      popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled:checked,
      button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled:checked,
      popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled:checked, popover.background.touch-selection button.suggested-action.osd
      button:backdrop:disabled:active, popover.background.magnifier button.suggested-action.osd
      button:backdrop:disabled:active, popover.background.touch-selection button.suggested-action.osd
      button:backdrop:disabled:checked, popover.background.magnifier button.suggested-action.osd
      button:backdrop:disabled:checked, popover.background.touch-selection button.suggested-action.osd
      button.flat:backdrop:disabled:active, popover.background.magnifier button.suggested-action.osd
      button.flat:backdrop:disabled:active, popover.background.touch-selection button.suggested-action.osd
      button.flat:backdrop:disabled:checked, popover.background.magnifier button.suggested-action.osd
      button.flat:backdrop:disabled:checked,
      button.suggested-action.osd
      button:backdrop:disabled:active,
      button.suggested-action.osd
      button:backdrop:disabled:checked,
      button.suggested-action.osd
      button.flat:backdrop:disabled:active,
      button.suggested-action.osd
      button.flat:backdrop:disabled:checked {
        color: rgba(232, 232, 232, 0.35);
        border-color: rgba(37, 164, 230, 0.35);
        background-image: linear-gradient(to bottom, rgba(44, 167, 231, 0.35), rgba(25, 152, 218, 0.35)); }
        popover.background.touch-selection button.suggested-action:backdrop:disabled:active > .label, popover.background.magnifier button.suggested-action:backdrop:disabled:active > .label, popover.background.touch-selection button.suggested-action:backdrop:disabled:checked > .label, popover.background.magnifier button.suggested-action:backdrop:disabled:checked > .label, popover.background.touch-selection button.suggested-action.flat:backdrop:disabled:active > .label, popover.background.magnifier button.suggested-action.flat:backdrop:disabled:active > .label, popover.background.touch-selection button.suggested-action.flat:backdrop:disabled:checked > .label, popover.background.magnifier button.suggested-action.flat:backdrop:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled:active > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button:backdrop:disabled:active > .label, popover.background.magnifier button.suggested-action.osd button:backdrop:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button:backdrop:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd button:backdrop:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled:active > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled:active > .label, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled:checked > .label,
        button.suggested-action:backdrop:disabled:active > .label,
        button.suggested-action:backdrop:disabled:checked > .label,
        button.suggested-action.flat:backdrop:disabled:active > .label,
        button.suggested-action.flat:backdrop:disabled:checked > .label,
        button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled:active > .label,
        popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled:active > .label,
        button.suggested-action.osd popover.background.magnifier button:backdrop:disabled:active > .label,
        popover.background.magnifier button.suggested-action.osd button:backdrop:disabled:active > .label,
        button.suggested-action.osd popover.background.touch-selection button:backdrop:disabled:checked > .label,
        popover.background.touch-selection button.suggested-action.osd button:backdrop:disabled:checked > .label,
        button.suggested-action.osd popover.background.magnifier button:backdrop:disabled:checked > .label,
        popover.background.magnifier button.suggested-action.osd button:backdrop:disabled:checked > .label,
        button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled:active > .label,
        popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled:active > .label,
        button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled:active > .label,
        popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled:active > .label,
        button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled:checked > .label,
        popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled:checked > .label,
        button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled:checked > .label,
        popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd
        button:backdrop:disabled:active > .label, popover.background.magnifier button.suggested-action.osd
        button:backdrop:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd
        button:backdrop:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd
        button:backdrop:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd
        button.flat:backdrop:disabled:active > .label, popover.background.magnifier button.suggested-action.osd
        button.flat:backdrop:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd
        button.flat:backdrop:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd
        button.flat:backdrop:disabled:checked > .label,
        button.suggested-action.osd
        button:backdrop:disabled:active > .label,
        button.suggested-action.osd
        button:backdrop:disabled:checked > .label,
        button.suggested-action.osd
        button.flat:backdrop:disabled:active > .label,
        button.suggested-action.osd
        button.flat:backdrop:disabled:checked > .label {
          color: inherit; }
  popover.background.touch-selection button.suggested-action.flat:backdrop, popover.background.magnifier button.suggested-action.flat:backdrop, popover.background.touch-selection button.suggested-action.flat:disabled, popover.background.magnifier button.suggested-action.flat:disabled, popover.background.touch-selection button.suggested-action.flat:backdrop:disabled, popover.background.magnifier button.suggested-action.flat:backdrop:disabled, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop, popover.background.magnifier button.suggested-action.osd button.flat:backdrop, popover.background.touch-selection button.suggested-action.osd button.flat:disabled, popover.background.magnifier button.suggested-action.osd button.flat:disabled, popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled, popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled,
  button.suggested-action.flat:backdrop,
  button.suggested-action.flat:disabled,
  button.suggested-action.flat:backdrop:disabled,
  button.suggested-action.osd popover.background.touch-selection button.flat:backdrop,
  popover.background.touch-selection button.suggested-action.osd button.flat:backdrop,
  button.suggested-action.osd popover.background.magnifier button.flat:backdrop,
  popover.background.magnifier button.suggested-action.osd button.flat:backdrop,
  button.suggested-action.osd popover.background.touch-selection button.flat:disabled,
  popover.background.touch-selection button.suggested-action.osd button.flat:disabled,
  button.suggested-action.osd popover.background.magnifier button.flat:disabled,
  popover.background.magnifier button.suggested-action.osd button.flat:disabled,
  button.suggested-action.osd popover.background.touch-selection button.flat:backdrop:disabled,
  popover.background.touch-selection button.suggested-action.osd button.flat:backdrop:disabled,
  button.suggested-action.osd popover.background.magnifier button.flat:backdrop:disabled,
  popover.background.magnifier button.suggested-action.osd button.flat:backdrop:disabled, popover.background.touch-selection button.suggested-action.osd
  button.flat:backdrop, popover.background.magnifier button.suggested-action.osd
  button.flat:backdrop, popover.background.touch-selection button.suggested-action.osd
  button.flat:disabled, popover.background.magnifier button.suggested-action.osd
  button.flat:disabled, popover.background.touch-selection button.suggested-action.osd
  button.flat:backdrop:disabled, popover.background.magnifier button.suggested-action.osd
  button.flat:backdrop:disabled,
  button.suggested-action.osd
  button.flat:backdrop,
  button.suggested-action.osd
  button.flat:disabled,
  button.suggested-action.osd
  button.flat:backdrop:disabled {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: rgba(61, 174, 233, 0.8); }
  popover.background.touch-selection button.suggested-action:disabled, popover.background.magnifier button.suggested-action:disabled, popover.background.touch-selection button.suggested-action.osd button:disabled, popover.background.magnifier button.suggested-action.osd button:disabled,
  button.suggested-action:disabled,
  button.suggested-action.osd popover.background.touch-selection button:disabled,
  popover.background.touch-selection button.suggested-action.osd button:disabled,
  button.suggested-action.osd popover.background.magnifier button:disabled,
  popover.background.magnifier button.suggested-action.osd button:disabled, popover.background.touch-selection button.suggested-action.osd
  button:disabled, popover.background.magnifier button.suggested-action.osd
  button:disabled,
  button.suggested-action.osd
  button:disabled {
    color: rgba(216, 218, 221, 0.35);
    border-color: rgba(88, 92, 95, 0.35);
    background-image: linear-gradient(to bottom, #2d3236, #2b3034); }
    popover.background.touch-selection button.suggested-action:disabled > .label, popover.background.magnifier button.suggested-action:disabled > .label, popover.background.touch-selection button.suggested-action.osd button:disabled > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button:disabled > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button:disabled > .label, popover.background.magnifier button.suggested-action.osd button:disabled > .label,
    button.suggested-action:disabled > .label,
    button.suggested-action.osd popover.background.touch-selection button:disabled > .label,
    popover.background.touch-selection button.suggested-action.osd button:disabled > .label,
    button.suggested-action.osd popover.background.magnifier button:disabled > .label,
    popover.background.magnifier button.suggested-action.osd button:disabled > .label, popover.background.touch-selection button.suggested-action.osd
    button:disabled > .label, popover.background.magnifier button.suggested-action.osd
    button:disabled > .label,
    button.suggested-action.osd
    button:disabled > .label {
      color: inherit; }
    popover.background.touch-selection button.suggested-action:disabled:active, popover.background.magnifier button.suggested-action:disabled:active, popover.background.touch-selection button.suggested-action:disabled:checked, popover.background.magnifier button.suggested-action:disabled:checked, popover.background.touch-selection button.suggested-action.osd button:disabled:active, popover.background.magnifier button.suggested-action.osd button:disabled:active, popover.background.touch-selection button.suggested-action.osd button:disabled:checked, popover.background.magnifier button.suggested-action.osd button:disabled:checked,
    button.suggested-action:disabled:active,
    button.suggested-action:disabled:checked,
    button.suggested-action.osd popover.background.touch-selection button:disabled:active,
    popover.background.touch-selection button.suggested-action.osd button:disabled:active,
    button.suggested-action.osd popover.background.magnifier button:disabled:active,
    popover.background.magnifier button.suggested-action.osd button:disabled:active,
    button.suggested-action.osd popover.background.touch-selection button:disabled:checked,
    popover.background.touch-selection button.suggested-action.osd button:disabled:checked,
    button.suggested-action.osd popover.background.magnifier button:disabled:checked,
    popover.background.magnifier button.suggested-action.osd button:disabled:checked, popover.background.touch-selection button.suggested-action.osd
    button:disabled:active, popover.background.magnifier button.suggested-action.osd
    button:disabled:active, popover.background.touch-selection button.suggested-action.osd
    button:disabled:checked, popover.background.magnifier button.suggested-action.osd
    button:disabled:checked,
    button.suggested-action.osd
    button:disabled:active,
    button.suggested-action.osd
    button:disabled:checked {
      color: rgba(232, 232, 232, 0.35);
      border-color: rgba(37, 164, 230, 0.35);
      background-image: linear-gradient(to bottom, rgba(44, 167, 231, 0.35), rgba(25, 152, 218, 0.35)); }
      popover.background.touch-selection button.suggested-action:disabled:active > .label, popover.background.magnifier button.suggested-action:disabled:active > .label, popover.background.touch-selection button.suggested-action:disabled:checked > .label, popover.background.magnifier button.suggested-action:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd button:disabled:active > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button:disabled:active > .label, popover.background.magnifier button.suggested-action.osd button:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd button:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd popover.background.touch-selection button:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd popover.background.magnifier button:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd button:disabled:checked > .label,
      button.suggested-action:disabled:active > .label,
      button.suggested-action:disabled:checked > .label,
      button.suggested-action.osd popover.background.touch-selection button:disabled:active > .label,
      popover.background.touch-selection button.suggested-action.osd button:disabled:active > .label,
      button.suggested-action.osd popover.background.magnifier button:disabled:active > .label,
      popover.background.magnifier button.suggested-action.osd button:disabled:active > .label,
      button.suggested-action.osd popover.background.touch-selection button:disabled:checked > .label,
      popover.background.touch-selection button.suggested-action.osd button:disabled:checked > .label,
      button.suggested-action.osd popover.background.magnifier button:disabled:checked > .label,
      popover.background.magnifier button.suggested-action.osd button:disabled:checked > .label, popover.background.touch-selection button.suggested-action.osd
      button:disabled:active > .label, popover.background.magnifier button.suggested-action.osd
      button:disabled:active > .label, popover.background.touch-selection button.suggested-action.osd
      button:disabled:checked > .label, popover.background.magnifier button.suggested-action.osd
      button:disabled:checked > .label,
      button.suggested-action.osd
      button:disabled:active > .label,
      button.suggested-action.osd
      button:disabled:checked > .label {
        color: inherit; }
popover.background.touch-selection button.destructive-action, popover.background.magnifier button.destructive-action, popover.background.touch-selection button.destructive-action.osd button, popover.background.magnifier button.destructive-action.osd button,
button.destructive-action,
button.destructive-action.osd popover.background.touch-selection button,
popover.background.touch-selection button.destructive-action.osd button,
button.destructive-action.osd popover.background.magnifier button,
popover.background.magnifier button.destructive-action.osd button, popover.background.touch-selection button.destructive-action.osd
button, popover.background.magnifier button.destructive-action.osd
button,
button.destructive-action.osd
button {
  box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.1);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #eff0f1;
  border-color: #da4453;
  background-image: linear-gradient(to bottom, #da4655, #d93d4d); }
  popover.background.touch-selection button.destructive-action.flat, popover.background.magnifier button.destructive-action.flat, popover.background.touch-selection button.destructive-action.osd button.flat, popover.background.magnifier button.destructive-action.osd button.flat,
  button.destructive-action.flat,
  button.destructive-action.osd popover.background.touch-selection button.flat,
  popover.background.touch-selection button.destructive-action.osd button.flat,
  button.destructive-action.osd popover.background.magnifier button.flat,
  popover.background.magnifier button.destructive-action.osd button.flat, popover.background.touch-selection button.destructive-action.osd
  button.flat, popover.background.magnifier button.destructive-action.osd
  button.flat,
  button.destructive-action.osd
  button.flat {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #da4453; }
  popover.background.touch-selection button.destructive-action:hover, popover.background.magnifier button.destructive-action:hover, popover.background.touch-selection button.destructive-action.osd button:hover, popover.background.magnifier button.destructive-action.osd button:hover,
  button.destructive-action:hover,
  button.destructive-action.osd popover.background.touch-selection button:hover,
  popover.background.touch-selection button.destructive-action.osd button:hover,
  button.destructive-action.osd popover.background.magnifier button:hover,
  popover.background.magnifier button.destructive-action.osd button:hover, popover.background.touch-selection button.destructive-action.osd
  button:hover, popover.background.magnifier button.destructive-action.osd
  button:hover,
  button.destructive-action.osd
  button:hover {
    color: white;
    border-color: #da4453; }
  popover.background.touch-selection button.destructive-action:active, popover.background.magnifier button.destructive-action:active, popover.background.touch-selection button.destructive-action:checked, popover.background.magnifier button.destructive-action:checked, popover.background.touch-selection button.destructive-action.osd button:active, popover.background.magnifier button.destructive-action.osd button:active, popover.background.touch-selection button.destructive-action.osd button:checked, popover.background.magnifier button.destructive-action.osd button:checked,
  button.destructive-action:active,
  button.destructive-action:checked,
  button.destructive-action.osd popover.background.touch-selection button:active,
  popover.background.touch-selection button.destructive-action.osd button:active,
  button.destructive-action.osd popover.background.magnifier button:active,
  popover.background.magnifier button.destructive-action.osd button:active,
  button.destructive-action.osd popover.background.touch-selection button:checked,
  popover.background.touch-selection button.destructive-action.osd button:checked,
  button.destructive-action.osd popover.background.magnifier button:checked,
  popover.background.magnifier button.destructive-action.osd button:checked, popover.background.touch-selection button.destructive-action.osd
  button:active, popover.background.magnifier button.destructive-action.osd
  button:active, popover.background.touch-selection button.destructive-action.osd
  button:checked, popover.background.magnifier button.destructive-action.osd
  button:checked,
  button.destructive-action.osd
  button:active,
  button.destructive-action.osd
  button:checked {
    color: white;
    border-color: #da4453;
    background-image: linear-gradient(to bottom, #db4b5a, #d62e3f); }
  popover.background.touch-selection button.destructive-action:backdrop, popover.background.magnifier button.destructive-action:backdrop, popover.background.touch-selection button.destructive-action.flat:backdrop, popover.background.magnifier button.destructive-action.flat:backdrop, popover.background.touch-selection button.destructive-action.osd button:backdrop, popover.background.magnifier button.destructive-action.osd button:backdrop, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop, popover.background.magnifier button.destructive-action.osd button.flat:backdrop,
  button.destructive-action:backdrop,
  button.destructive-action.flat:backdrop,
  button.destructive-action.osd popover.background.touch-selection button:backdrop,
  popover.background.touch-selection button.destructive-action.osd button:backdrop,
  button.destructive-action.osd popover.background.magnifier button:backdrop,
  popover.background.magnifier button.destructive-action.osd button:backdrop,
  button.destructive-action.osd popover.background.touch-selection button.flat:backdrop,
  popover.background.touch-selection button.destructive-action.osd button.flat:backdrop,
  button.destructive-action.osd popover.background.magnifier button.flat:backdrop,
  popover.background.magnifier button.destructive-action.osd button.flat:backdrop, popover.background.touch-selection button.destructive-action.osd
  button:backdrop, popover.background.magnifier button.destructive-action.osd
  button:backdrop, popover.background.touch-selection button.destructive-action.osd
  button.flat:backdrop, popover.background.magnifier button.destructive-action.osd
  button.flat:backdrop,
  button.destructive-action.osd
  button:backdrop,
  button.destructive-action.osd
  button.flat:backdrop {
    color: white;
    border-color: #616569;
    background-image: linear-gradient(to bottom, #da4655, #d93d4d); }
    popover.background.touch-selection button.destructive-action:backdrop:active, popover.background.magnifier button.destructive-action:backdrop:active, popover.background.touch-selection button.destructive-action:backdrop:checked, popover.background.magnifier button.destructive-action:backdrop:checked, popover.background.touch-selection button.destructive-action.flat:backdrop:active, popover.background.magnifier button.destructive-action.flat:backdrop:active, popover.background.touch-selection button.destructive-action.flat:backdrop:checked, popover.background.magnifier button.destructive-action.flat:backdrop:checked, popover.background.touch-selection button.destructive-action.osd button:backdrop:active, popover.background.magnifier button.destructive-action.osd button:backdrop:active, popover.background.touch-selection button.destructive-action.osd button:backdrop:checked, popover.background.magnifier button.destructive-action.osd button:backdrop:checked, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:active, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:active, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:checked, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:checked,
    button.destructive-action:backdrop:active,
    button.destructive-action:backdrop:checked,
    button.destructive-action.flat:backdrop:active,
    button.destructive-action.flat:backdrop:checked,
    button.destructive-action.osd popover.background.touch-selection button:backdrop:active,
    popover.background.touch-selection button.destructive-action.osd button:backdrop:active,
    button.destructive-action.osd popover.background.magnifier button:backdrop:active,
    popover.background.magnifier button.destructive-action.osd button:backdrop:active,
    button.destructive-action.osd popover.background.touch-selection button:backdrop:checked,
    popover.background.touch-selection button.destructive-action.osd button:backdrop:checked,
    button.destructive-action.osd popover.background.magnifier button:backdrop:checked,
    popover.background.magnifier button.destructive-action.osd button:backdrop:checked,
    button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:active,
    popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:active,
    button.destructive-action.osd popover.background.magnifier button.flat:backdrop:active,
    popover.background.magnifier button.destructive-action.osd button.flat:backdrop:active,
    button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:checked,
    popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:checked,
    button.destructive-action.osd popover.background.magnifier button.flat:backdrop:checked,
    popover.background.magnifier button.destructive-action.osd button.flat:backdrop:checked, popover.background.touch-selection button.destructive-action.osd
    button:backdrop:active, popover.background.magnifier button.destructive-action.osd
    button:backdrop:active, popover.background.touch-selection button.destructive-action.osd
    button:backdrop:checked, popover.background.magnifier button.destructive-action.osd
    button:backdrop:checked, popover.background.touch-selection button.destructive-action.osd
    button.flat:backdrop:active, popover.background.magnifier button.destructive-action.osd
    button.flat:backdrop:active, popover.background.touch-selection button.destructive-action.osd
    button.flat:backdrop:checked, popover.background.magnifier button.destructive-action.osd
    button.flat:backdrop:checked,
    button.destructive-action.osd
    button:backdrop:active,
    button.destructive-action.osd
    button:backdrop:checked,
    button.destructive-action.osd
    button.flat:backdrop:active,
    button.destructive-action.osd
    button.flat:backdrop:checked {
      color: white;
      border-color: #da4453;
      background-image: linear-gradient(to bottom, #db4b5a, #d62e3f); }
    popover.background.touch-selection button.destructive-action:backdrop:disabled, popover.background.magnifier button.destructive-action:backdrop:disabled, popover.background.touch-selection button.destructive-action.flat:backdrop:disabled, popover.background.magnifier button.destructive-action.flat:backdrop:disabled, popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled, popover.background.magnifier button.destructive-action.osd button:backdrop:disabled, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled,
    button.destructive-action:backdrop:disabled,
    button.destructive-action.flat:backdrop:disabled,
    button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled,
    popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled,
    button.destructive-action.osd popover.background.magnifier button:backdrop:disabled,
    popover.background.magnifier button.destructive-action.osd button:backdrop:disabled,
    button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled,
    popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled,
    button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled,
    popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled, popover.background.touch-selection button.destructive-action.osd
    button:backdrop:disabled, popover.background.magnifier button.destructive-action.osd
    button:backdrop:disabled, popover.background.touch-selection button.destructive-action.osd
    button.flat:backdrop:disabled, popover.background.magnifier button.destructive-action.osd
    button.flat:backdrop:disabled,
    button.destructive-action.osd
    button:backdrop:disabled,
    button.destructive-action.osd
    button.flat:backdrop:disabled {
      color: rgba(216, 218, 221, 0.35);
      border-color: rgba(88, 92, 95, 0.35);
      background-image: linear-gradient(to bottom, #2d3236, #2b3034); }
      popover.background.touch-selection button.destructive-action:backdrop:disabled > .label, popover.background.magnifier button.destructive-action:backdrop:disabled > .label, popover.background.touch-selection button.destructive-action.flat:backdrop:disabled > .label, popover.background.magnifier button.destructive-action.flat:backdrop:disabled > .label, popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button:backdrop:disabled > .label, popover.background.magnifier button.destructive-action.osd button:backdrop:disabled > .label, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled > .label, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled > .label,
      button.destructive-action:backdrop:disabled > .label,
      button.destructive-action.flat:backdrop:disabled > .label,
      button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled > .label,
      popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled > .label,
      button.destructive-action.osd popover.background.magnifier button:backdrop:disabled > .label,
      popover.background.magnifier button.destructive-action.osd button:backdrop:disabled > .label,
      button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled > .label,
      popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled > .label,
      button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled > .label,
      popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled > .label, popover.background.touch-selection button.destructive-action.osd
      button:backdrop:disabled > .label, popover.background.magnifier button.destructive-action.osd
      button:backdrop:disabled > .label, popover.background.touch-selection button.destructive-action.osd
      button.flat:backdrop:disabled > .label, popover.background.magnifier button.destructive-action.osd
      button.flat:backdrop:disabled > .label,
      button.destructive-action.osd
      button:backdrop:disabled > .label,
      button.destructive-action.osd
      button.flat:backdrop:disabled > .label {
        color: inherit; }
      popover.background.touch-selection button.destructive-action:backdrop:disabled:active, popover.background.magnifier button.destructive-action:backdrop:disabled:active, popover.background.touch-selection button.destructive-action:backdrop:disabled:checked, popover.background.magnifier button.destructive-action:backdrop:disabled:checked, popover.background.touch-selection button.destructive-action.flat:backdrop:disabled:active, popover.background.magnifier button.destructive-action.flat:backdrop:disabled:active, popover.background.touch-selection button.destructive-action.flat:backdrop:disabled:checked, popover.background.magnifier button.destructive-action.flat:backdrop:disabled:checked, popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled:active, popover.background.magnifier button.destructive-action.osd button:backdrop:disabled:active, popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled:checked, popover.background.magnifier button.destructive-action.osd button:backdrop:disabled:checked, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled:active, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled:active, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled:checked, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled:checked,
      button.destructive-action:backdrop:disabled:active,
      button.destructive-action:backdrop:disabled:checked,
      button.destructive-action.flat:backdrop:disabled:active,
      button.destructive-action.flat:backdrop:disabled:checked,
      button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled:active,
      popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled:active,
      button.destructive-action.osd popover.background.magnifier button:backdrop:disabled:active,
      popover.background.magnifier button.destructive-action.osd button:backdrop:disabled:active,
      button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled:checked,
      popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled:checked,
      button.destructive-action.osd popover.background.magnifier button:backdrop:disabled:checked,
      popover.background.magnifier button.destructive-action.osd button:backdrop:disabled:checked,
      button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled:active,
      popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled:active,
      button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled:active,
      popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled:active,
      button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled:checked,
      popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled:checked,
      button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled:checked,
      popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled:checked, popover.background.touch-selection button.destructive-action.osd
      button:backdrop:disabled:active, popover.background.magnifier button.destructive-action.osd
      button:backdrop:disabled:active, popover.background.touch-selection button.destructive-action.osd
      button:backdrop:disabled:checked, popover.background.magnifier button.destructive-action.osd
      button:backdrop:disabled:checked, popover.background.touch-selection button.destructive-action.osd
      button.flat:backdrop:disabled:active, popover.background.magnifier button.destructive-action.osd
      button.flat:backdrop:disabled:active, popover.background.touch-selection button.destructive-action.osd
      button.flat:backdrop:disabled:checked, popover.background.magnifier button.destructive-action.osd
      button.flat:backdrop:disabled:checked,
      button.destructive-action.osd
      button:backdrop:disabled:active,
      button.destructive-action.osd
      button:backdrop:disabled:checked,
      button.destructive-action.osd
      button.flat:backdrop:disabled:active,
      button.destructive-action.osd
      button.flat:backdrop:disabled:checked {
        color: rgba(232, 232, 232, 0.35);
        border-color: rgba(214, 46, 63, 0.35);
        background-image: linear-gradient(to bottom, rgba(215, 53, 69, 0.35), rgba(197, 39, 55, 0.35)); }
        popover.background.touch-selection button.destructive-action:backdrop:disabled:active > .label, popover.background.magnifier button.destructive-action:backdrop:disabled:active > .label, popover.background.touch-selection button.destructive-action:backdrop:disabled:checked > .label, popover.background.magnifier button.destructive-action:backdrop:disabled:checked > .label, popover.background.touch-selection button.destructive-action.flat:backdrop:disabled:active > .label, popover.background.magnifier button.destructive-action.flat:backdrop:disabled:active > .label, popover.background.touch-selection button.destructive-action.flat:backdrop:disabled:checked > .label, popover.background.magnifier button.destructive-action.flat:backdrop:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled:active > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button:backdrop:disabled:active > .label, popover.background.magnifier button.destructive-action.osd button:backdrop:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button:backdrop:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd button:backdrop:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled:active > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled:active > .label, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled:checked > .label,
        button.destructive-action:backdrop:disabled:active > .label,
        button.destructive-action:backdrop:disabled:checked > .label,
        button.destructive-action.flat:backdrop:disabled:active > .label,
        button.destructive-action.flat:backdrop:disabled:checked > .label,
        button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled:active > .label,
        popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled:active > .label,
        button.destructive-action.osd popover.background.magnifier button:backdrop:disabled:active > .label,
        popover.background.magnifier button.destructive-action.osd button:backdrop:disabled:active > .label,
        button.destructive-action.osd popover.background.touch-selection button:backdrop:disabled:checked > .label,
        popover.background.touch-selection button.destructive-action.osd button:backdrop:disabled:checked > .label,
        button.destructive-action.osd popover.background.magnifier button:backdrop:disabled:checked > .label,
        popover.background.magnifier button.destructive-action.osd button:backdrop:disabled:checked > .label,
        button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled:active > .label,
        popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled:active > .label,
        button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled:active > .label,
        popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled:active > .label,
        button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled:checked > .label,
        popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled:checked > .label,
        button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled:checked > .label,
        popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd
        button:backdrop:disabled:active > .label, popover.background.magnifier button.destructive-action.osd
        button:backdrop:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd
        button:backdrop:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd
        button:backdrop:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd
        button.flat:backdrop:disabled:active > .label, popover.background.magnifier button.destructive-action.osd
        button.flat:backdrop:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd
        button.flat:backdrop:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd
        button.flat:backdrop:disabled:checked > .label,
        button.destructive-action.osd
        button:backdrop:disabled:active > .label,
        button.destructive-action.osd
        button:backdrop:disabled:checked > .label,
        button.destructive-action.osd
        button.flat:backdrop:disabled:active > .label,
        button.destructive-action.osd
        button.flat:backdrop:disabled:checked > .label {
          color: inherit; }
  popover.background.touch-selection button.destructive-action.flat:backdrop, popover.background.magnifier button.destructive-action.flat:backdrop, popover.background.touch-selection button.destructive-action.flat:disabled, popover.background.magnifier button.destructive-action.flat:disabled, popover.background.touch-selection button.destructive-action.flat:backdrop:disabled, popover.background.magnifier button.destructive-action.flat:backdrop:disabled, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop, popover.background.magnifier button.destructive-action.osd button.flat:backdrop, popover.background.touch-selection button.destructive-action.osd button.flat:disabled, popover.background.magnifier button.destructive-action.osd button.flat:disabled, popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled, popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled,
  button.destructive-action.flat:backdrop,
  button.destructive-action.flat:disabled,
  button.destructive-action.flat:backdrop:disabled,
  button.destructive-action.osd popover.background.touch-selection button.flat:backdrop,
  popover.background.touch-selection button.destructive-action.osd button.flat:backdrop,
  button.destructive-action.osd popover.background.magnifier button.flat:backdrop,
  popover.background.magnifier button.destructive-action.osd button.flat:backdrop,
  button.destructive-action.osd popover.background.touch-selection button.flat:disabled,
  popover.background.touch-selection button.destructive-action.osd button.flat:disabled,
  button.destructive-action.osd popover.background.magnifier button.flat:disabled,
  popover.background.magnifier button.destructive-action.osd button.flat:disabled,
  button.destructive-action.osd popover.background.touch-selection button.flat:backdrop:disabled,
  popover.background.touch-selection button.destructive-action.osd button.flat:backdrop:disabled,
  button.destructive-action.osd popover.background.magnifier button.flat:backdrop:disabled,
  popover.background.magnifier button.destructive-action.osd button.flat:backdrop:disabled, popover.background.touch-selection button.destructive-action.osd
  button.flat:backdrop, popover.background.magnifier button.destructive-action.osd
  button.flat:backdrop, popover.background.touch-selection button.destructive-action.osd
  button.flat:disabled, popover.background.magnifier button.destructive-action.osd
  button.flat:disabled, popover.background.touch-selection button.destructive-action.osd
  button.flat:backdrop:disabled, popover.background.magnifier button.destructive-action.osd
  button.flat:backdrop:disabled,
  button.destructive-action.osd
  button.flat:backdrop,
  button.destructive-action.osd
  button.flat:disabled,
  button.destructive-action.osd
  button.flat:backdrop:disabled {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: rgba(218, 68, 83, 0.8); }
  popover.background.touch-selection button.destructive-action:disabled, popover.background.magnifier button.destructive-action:disabled, popover.background.touch-selection button.destructive-action.osd button:disabled, popover.background.magnifier button.destructive-action.osd button:disabled,
  button.destructive-action:disabled,
  button.destructive-action.osd popover.background.touch-selection button:disabled,
  popover.background.touch-selection button.destructive-action.osd button:disabled,
  button.destructive-action.osd popover.background.magnifier button:disabled,
  popover.background.magnifier button.destructive-action.osd button:disabled, popover.background.touch-selection button.destructive-action.osd
  button:disabled, popover.background.magnifier button.destructive-action.osd
  button:disabled,
  button.destructive-action.osd
  button:disabled {
    color: rgba(216, 218, 221, 0.35);
    border-color: rgba(88, 92, 95, 0.35);
    background-image: linear-gradient(to bottom, #2d3236, #2b3034); }
    popover.background.touch-selection button.destructive-action:disabled > .label, popover.background.magnifier button.destructive-action:disabled > .label, popover.background.touch-selection button.destructive-action.osd button:disabled > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button:disabled > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button:disabled > .label, popover.background.magnifier button.destructive-action.osd button:disabled > .label,
    button.destructive-action:disabled > .label,
    button.destructive-action.osd popover.background.touch-selection button:disabled > .label,
    popover.background.touch-selection button.destructive-action.osd button:disabled > .label,
    button.destructive-action.osd popover.background.magnifier button:disabled > .label,
    popover.background.magnifier button.destructive-action.osd button:disabled > .label, popover.background.touch-selection button.destructive-action.osd
    button:disabled > .label, popover.background.magnifier button.destructive-action.osd
    button:disabled > .label,
    button.destructive-action.osd
    button:disabled > .label {
      color: inherit; }
    popover.background.touch-selection button.destructive-action:disabled:active, popover.background.magnifier button.destructive-action:disabled:active, popover.background.touch-selection button.destructive-action:disabled:checked, popover.background.magnifier button.destructive-action:disabled:checked, popover.background.touch-selection button.destructive-action.osd button:disabled:active, popover.background.magnifier button.destructive-action.osd button:disabled:active, popover.background.touch-selection button.destructive-action.osd button:disabled:checked, popover.background.magnifier button.destructive-action.osd button:disabled:checked,
    button.destructive-action:disabled:active,
    button.destructive-action:disabled:checked,
    button.destructive-action.osd popover.background.touch-selection button:disabled:active,
    popover.background.touch-selection button.destructive-action.osd button:disabled:active,
    button.destructive-action.osd popover.background.magnifier button:disabled:active,
    popover.background.magnifier button.destructive-action.osd button:disabled:active,
    button.destructive-action.osd popover.background.touch-selection button:disabled:checked,
    popover.background.touch-selection button.destructive-action.osd button:disabled:checked,
    button.destructive-action.osd popover.background.magnifier button:disabled:checked,
    popover.background.magnifier button.destructive-action.osd button:disabled:checked, popover.background.touch-selection button.destructive-action.osd
    button:disabled:active, popover.background.magnifier button.destructive-action.osd
    button:disabled:active, popover.background.touch-selection button.destructive-action.osd
    button:disabled:checked, popover.background.magnifier button.destructive-action.osd
    button:disabled:checked,
    button.destructive-action.osd
    button:disabled:active,
    button.destructive-action.osd
    button:disabled:checked {
      color: rgba(232, 232, 232, 0.35);
      border-color: rgba(37, 164, 230, 0.35);
      background-image: linear-gradient(to bottom, rgba(215, 53, 69, 0.35), rgba(197, 39, 55, 0.35)); }
      popover.background.touch-selection button.destructive-action:disabled:active > .label, popover.background.magnifier button.destructive-action:disabled:active > .label, popover.background.touch-selection button.destructive-action:disabled:checked > .label, popover.background.magnifier button.destructive-action:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd button:disabled:active > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button:disabled:active > .label, popover.background.magnifier button.destructive-action.osd button:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd button:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd popover.background.touch-selection button:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd popover.background.magnifier button:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd button:disabled:checked > .label,
      button.destructive-action:disabled:active > .label,
      button.destructive-action:disabled:checked > .label,
      button.destructive-action.osd popover.background.touch-selection button:disabled:active > .label,
      popover.background.touch-selection button.destructive-action.osd button:disabled:active > .label,
      button.destructive-action.osd popover.background.magnifier button:disabled:active > .label,
      popover.background.magnifier button.destructive-action.osd button:disabled:active > .label,
      button.destructive-action.osd popover.background.touch-selection button:disabled:checked > .label,
      popover.background.touch-selection button.destructive-action.osd button:disabled:checked > .label,
      button.destructive-action.osd popover.background.magnifier button:disabled:checked > .label,
      popover.background.magnifier button.destructive-action.osd button:disabled:checked > .label, popover.background.touch-selection button.destructive-action.osd
      button:disabled:active > .label, popover.background.magnifier button.destructive-action.osd
      button:disabled:active > .label, popover.background.touch-selection button.destructive-action.osd
      button:disabled:checked > .label, popover.background.magnifier button.destructive-action.osd
      button:disabled:checked > .label,
      button.destructive-action.osd
      button:disabled:active > .label,
      button.destructive-action.osd
      button:disabled:checked > .label {
        color: inherit; }
popover.background.touch-selection .stack-switcher > button > label, popover.background.magnifier .stack-switcher > button > label, .stack-switcher >
button > label {
  padding-left: 6px;
  padding-right: 6px; }
popover.background.touch-selection .stack-switcher > button > image, popover.background.magnifier .stack-switcher > button > image, .stack-switcher >
button > image {
  padding-left: 6px;
  padding-right: 6px;
  padding-top: 3px;
  padding-bottom: 3px; }
popover.background.touch-selection .stack-switcher > button.text-button, popover.background.magnifier .stack-switcher > button.text-button, .stack-switcher >
button.text-button {
  padding: 6px; }
popover.background.touch-selection .stack-switcher > button.image-button, popover.background.magnifier .stack-switcher > button.image-button, .stack-switcher >
button.image-button {
  padding: 3px 0px; }
popover.background.touch-selection .stack-switcher > button.needs-attention:active > label, popover.background.magnifier .stack-switcher > button.needs-attention:active > label, popover.background.touch-selection .stack-switcher > button.needs-attention:active > image, popover.background.magnifier .stack-switcher > button.needs-attention:active > image, popover.background.touch-selection .stack-switcher > button.needs-attention:checked > label, popover.background.magnifier .stack-switcher > button.needs-attention:checked > label, popover.background.touch-selection .stack-switcher > button.needs-attention:checked > image, popover.background.magnifier .stack-switcher > button.needs-attention:checked > image, .stack-switcher >
button.needs-attention:active > label, .stack-switcher >
button.needs-attention:active > image, .stack-switcher >
button.needs-attention:checked > label, .stack-switcher >
button.needs-attention:checked > image {
  animation: none;
  background-image: none; }
.inline-toolbar popover.background.touch-selection button, popover.background.touch-selection .inline-toolbar button, .inline-toolbar popover.background.magnifier button, popover.background.magnifier .inline-toolbar button, .inline-toolbar popover.background.touch-selection button:backdrop, popover.background.touch-selection .inline-toolbar button:backdrop, .inline-toolbar popover.background.magnifier button:backdrop, popover.background.magnifier .inline-toolbar button:backdrop, .inline-toolbar
button, .inline-toolbar
button:backdrop {
  border-radius: 3px;
  border-width: 1px; }
.primary-toolbar popover.background.touch-selection button, popover.background.touch-selection .primary-toolbar button, .primary-toolbar popover.background.magnifier button, popover.background.magnifier .primary-toolbar button, .primary-toolbar
button {
  -gtk-icon-shadow: none; }

/**************
 * ComboBoxes *
 **************/
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px; }

popover.background.touch-selection .stack-switcher > button.needs-attention > label, popover.background.magnifier .stack-switcher > button.needs-attention > label, popover.background.touch-selection .stack-switcher > button.needs-attention > image, popover.background.magnifier .stack-switcher > button.needs-attention > image, .stack-switcher >
button.needs-attention > label, .stack-switcher >
button.needs-attention > image, stacksidebar.sidebar row.needs-attention > .label {
  animation: needs_attention 150ms ease-in;
  background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#3daee9), to(transparent)), -gtk-gradient(radial, center center, 0, center center, 0.5, to(#eff0f1), to(transparent));
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 4px; }
  .stack-switcher >
  button.needs-attention > label:backdrop, .stack-switcher >
  button.needs-attention > image:backdrop, stacksidebar.sidebar row.needs-attention > .label:backdrop {
    background-size: 6px 6px, 0 0; }
  .stack-switcher >
  button.needs-attention > label:dir(rtl), .stack-switcher >
  button.needs-attention > image:dir(rtl), stacksidebar.sidebar row.needs-attention > .label:dir(rtl) {
    background-position: left 3px, left 4px; }

.linked > combobox > box > button.combo:dir(ltr), .linked > combobox > box > button.combo:dir(rtl), .inline-toolbar popover.background.touch-selection button, popover.background.touch-selection .inline-toolbar button, .inline-toolbar popover.background.magnifier button, popover.background.magnifier .inline-toolbar button, .inline-toolbar
button, .inline-toolbar
button:backdrop, popover.background.touch-selection .linked > button, popover.background.magnifier .linked > button, .linked >
button, .linked >
button:hover, .linked >
button:active, .linked >
button:checked, .linked >
button:backdrop {
  border-radius: 3px; }
  .linked > combobox > box > button.combo:dir(rtl), .inline-toolbar popover.background.touch-selection button:dir(rtl), popover.background.touch-selection .inline-toolbar button:dir(rtl), .inline-toolbar popover.background.magnifier button:dir(rtl), popover.background.magnifier .inline-toolbar button:dir(rtl), .inline-toolbar
  button:dir(rtl), popover.background.touch-selection .linked > button:dir(rtl), popover.background.magnifier .linked > button:dir(rtl), .linked >
  button:dir(rtl) {
    border-radius: 3px; }

.inline-toolbar popover.background.touch-selection button, popover.background.touch-selection .inline-toolbar button, .inline-toolbar popover.background.magnifier button, popover.background.magnifier .inline-toolbar button, .inline-toolbar
button, .inline-toolbar
button:backdrop, popover.background.touch-selection .linked > button, popover.background.magnifier .linked > button, .linked >
button, .linked >
button:hover, .linked >
button:active, .linked >
button:checked, .linked >
button:backdrop {
  margin-left: 2px;
  margin-right: 2px; }
  .inline-toolbar popover.background.touch-selection button:first-child, popover.background.touch-selection .inline-toolbar button:first-child, .inline-toolbar popover.background.magnifier button:first-child, popover.background.magnifier .inline-toolbar button:first-child, .inline-toolbar
  button:first-child, popover.background.touch-selection .linked > button:first-child, popover.background.magnifier .linked > button:first-child, .linked >
  button:first-child, combobox.linked button:nth-child(2):dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.combo {
    border-radius: 3px;
    border-style: solid; }
  .inline-toolbar popover.background.touch-selection button:last-child, popover.background.touch-selection .inline-toolbar button:last-child, .inline-toolbar popover.background.magnifier button:last-child, popover.background.magnifier .inline-toolbar button:last-child, .inline-toolbar
  button:last-child, popover.background.touch-selection .linked > button:last-child, popover.background.magnifier .linked > button:last-child, .linked >
  button:last-child, combobox.linked button:nth-child(2):dir(ltr), .linked:not(.vertical) > combobox:last-child > box > button.combo {
    border-radius: 3px; }
  .inline-toolbar popover.background.touch-selection button:only-child, popover.background.touch-selection .inline-toolbar button:only-child, .inline-toolbar popover.background.magnifier button:only-child, popover.background.magnifier .inline-toolbar button:only-child, .inline-toolbar
  button:only-child, popover.background.touch-selection .linked > button:only-child, popover.background.magnifier .linked > button:only-child, .linked >
  button:only-child, .linked:not(.vertical) > combobox:only-child > box > button.combo {
    border-radius: 3px;
    border-style: solid; }

.linked.vertical > combobox > box > button.combo, popover.background.touch-selection .linked.vertical > button, popover.background.magnifier .linked.vertical > button, .linked.vertical >
button, .linked.vertical >
button:hover, .linked.vertical >
button:active, .linked.vertical >
button:checked, .linked.vertical >
button:backdrop {
  border-style: solid;
  border-radius: 3px; }

popover.background.touch-selection .linked.vertical > button:first-child, popover.background.magnifier .linked.vertical > button:first-child, .linked.vertical >
button:first-child, .linked.vertical > combobox:first-child > box > button.combo {
  border-radius: 3px; }
popover.background.touch-selection .linked.vertical > button:last-child, popover.background.magnifier .linked.vertical > button:last-child, .linked.vertical >
button:last-child, .linked.vertical > combobox:last-child > box > button.combo {
  border-radius: 3px;
  border-style: solid; }
popover.background.touch-selection .linked.vertical > button:only-child, popover.background.magnifier .linked.vertical > button:only-child, .linked.vertical >
button:only-child, .linked.vertical > combobox:only-child > box > button.combo {
  border-radius: 3px;
  border-style: solid; }

.app-notification button.flat,
.app-notification.frame button.flat, .app-notification button.flat:hover,
.app-notification.frame button.flat:hover, .app-notification button.flat:active,
.app-notification.frame button.flat:active, .app-notification button.flat:backdrop, .app-notification button.flat:disabled, .app-notification button.flat:backdrop:disabled,
.app-notification.frame button.flat:backdrop,
.app-notification.frame button.flat:disabled,
.app-notification.frame button.flat:backdrop:disabled, calendar.button, calendar.button:hover, calendar.button:active, calendar.button:backdrop,
headerbar button.flat:disabled, button:link,
button:visited, button:link:hover, button:link:active, button:link:checked,
button:visited:hover,
button:visited:active,
button:visited:checked, modelbutton.flat, popover.background checkbutton,
popover.background radiobutton,
.menuitem.button.flat, modelbutton.flat:backdrop, popover.background checkbutton:backdrop,
popover.background radiobutton:backdrop, modelbutton.flat:backdrop:hover, popover.background checkbutton:backdrop:hover,
popover.background radiobutton:backdrop:hover,
.menuitem.button.flat:backdrop,
.menuitem.button.flat:backdrop:hover, scrollbar button:backdrop, button.sidebar-button {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  text-shadow: none;
  -gtk-icon-shadow: none; }

/****************
 * Text Entries *
 ****************/
spinbutton:not(.vertical),
entry {
  min-height: 30px;
  padding-left: 8px;
  padding-right: 8px;
  border: 1px solid;
  border-radius: 3px;
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  color: #eff0f1;
  border-color: #616569;
  background-color: #232629;
  box-shadow: none; }
  spinbutton:not(.vertical) image.left,
  entry image.left {
    padding-left: 0;
    padding-right: 6px; }
  spinbutton:not(.vertical) image.right,
  entry image.right {
    padding-left: 6px;
    padding-right: 0; }
  spinbutton.flat:focus:not(.vertical), spinbutton.flat:not(.vertical),
  entry.flat:focus,
  entry.flat {
    min-height: 0;
    padding: 2px;
    color: #eff0f1;
    border-color: #616569;
    background-color: #232629;
    box-shadow: none; }
  spinbutton:focus:not(.vertical),
  entry:focus {
    border-color: #3daee9; }
  spinbutton:disabled:not(.vertical),
  entry:disabled {
    color: rgba(216, 218, 221, 0.35);
    border-color: rgba(88, 92, 95, 0.35);
    background-color: #202325; }
  spinbutton:backdrop:not(.vertical),
  entry:backdrop {
    color: #eff0f1;
    border-color: #616569;
    background-color: #232629; }
  spinbutton:backdrop:disabled:not(.vertical),
  entry:backdrop:disabled {
    color: rgba(216, 218, 221, 0.35);
    border-color: rgba(88, 92, 95, 0.35);
    background-color: #202325; }
  spinbutton.error:not(.vertical),
  entry.error {
    color: #da4453;
    border-color: #da4453;
    background-color: rgba(218, 68, 83, 0.5); }
    spinbutton.error:focus:not(.vertical),
    entry.error:focus {
      border-color: #da4453;
      background-color: rgba(218, 68, 83, 0.5); }
    spinbutton.error:selected:not(.vertical), spinbutton.error:selected:focus:not(.vertical),
    entry.error:selected,
    entry.error:selected:focus {
      background-color: #da4453; }
    spinbutton.error:backdrop:not(.vertical),
    entry.error:backdrop {
      color: #da4453;
      border-color: #da4453;
      background-color: rgba(218, 68, 83, 0.5); }
  spinbutton.warning:not(.vertical),
  entry.warning {
    color: #f67400;
    border-color: #f67400;
    background-color: rgba(246, 116, 0, 0.5); }
    spinbutton.warning:focus:not(.vertical),
    entry.warning:focus {
      border-color: #f67400;
      background-color: rgba(246, 116, 0, 0.5); }
    spinbutton.warning:selected:not(.vertical), spinbutton.warning:selected:focus:not(.vertical),
    entry.warning:selected,
    entry.warning:selected:focus {
      background-color: #f67400; }
    spinbutton.warning:backdrop:not(.vertical),
    entry.warning:backdrop {
      color: #f67400;
      border-color: #f67400;
      background-color: rgba(246, 116, 0, 0.5); }
  spinbutton:not(.vertical) image,
  entry image {
    color: #eff0f1; }
    spinbutton:not(.vertical) image:hover,
    entry image:hover {
      color: #3daee9; }
    spinbutton:not(.vertical) image:active,
    entry image:active {
      color: #3daee9; }
    spinbutton:not(.vertical) image:backdrop,
    entry image:backdrop {
      color: #eff0f1; }
spinbutton:not(.vertical) progress,
entry progress {
  margin: 1px;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #3daee9;
  border-style: solid;
  background-image: none;
  background-color: transparent;
  box-shadow: none; }
  spinbutton:not(.vertical) progress:backdrop,
  entry progress:backdrop {
    background-color: transparent;
    border-color: rgba(61, 174, 233, 0.5); }

treeview acceleditor > label {
  background-color: #3daee9; }

treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: #232629; }
  treeview entry.flat:focus, treeview entry:focus {
    border-color: #3daee9; }

/*********************
 * App Notifications *
 *********************/
.app-notification,
.app-notification.frame {
  padding: 10px;
  border-top-width: 0px;
  border-radius: 0px 0px 3px 3px; }
  .app-notification:backdrop,
  .app-notification.frame:backdrop {
    background-image: none; }
  .app-notification button,
  .app-notification.frame button {
    box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.1);
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #eff0f1;
    border-color: #616569;
    background-image: linear-gradient(to bottom, #31373c, #303439); }
    .app-notification button.flat,
    .app-notification.frame button.flat {
      -gtk-icon-shadow: none;
      text-shadow: none; }
      .app-notification button.flat:hover,
      .app-notification.frame button.flat:hover {
        color: #3daee9; }
      .app-notification button.flat:active,
      .app-notification.frame button.flat:active {
        color: #3daee9; }
    .app-notification button:hover,
    .app-notification.frame button:hover {
      color: #eff0f1;
      border-color: #3daee9; }
    .app-notification button:active, .app-notification button:checked, .app-notification button:backdrop:active, .app-notification button:backdrop:checked,
    .app-notification.frame button:active,
    .app-notification.frame button:checked,
    .app-notification.frame button:backdrop:active,
    .app-notification.frame button:backdrop:checked {
      color: #eff0f1;
      border-color: #3daee9;
      background-image: linear-gradient(to bottom, #45b1ea, #25a4e6); }
    .app-notification button:disabled, .app-notification button:backdrop:disabled,
    .app-notification.frame button:disabled,
    .app-notification.frame button:backdrop:disabled {
      color: rgba(216, 218, 221, 0.35);
      border-color: rgba(88, 92, 95, 0.35);
      background-image: linear-gradient(to bottom, #2d3236, #2b3034); }
      .app-notification button:disabled > .label, .app-notification button:backdrop:disabled > .label,
      .app-notification.frame button:disabled > .label,
      .app-notification.frame button:backdrop:disabled > .label {
        color: inherit; }
    .app-notification button:backdrop,
    .app-notification.frame button:backdrop {
      color: #eff0f1;
      border-color: #616569;
      background-image: linear-gradient(to bottom, #31373c, #303439); }
  .app-notification border,
  .app-notification.frame border {
    border: none; }

/************
 * Calendar *
 ***********/
calendar {
  color: #eff0f1;
  border: 1px solid #616569;
  background-color: #232629; }
  calendar:selected {
    background-color: #616569; }
  calendar.header {
    border: 1px solid #616569;
    border-radius: 0;
    color: #eff0f1; }
    calendar.header:backdrop {
      color: #eff0f1;
      border-color: #616569; }
  calendar.button {
    color: #eff0f1; }
    calendar.button:hover {
      color: #3daee9; }
    calendar.button:active {
      color: #3daee9; }
    calendar.button:backdrop {
      color: #eff0f1; }
  calendar:indeterminate, calendar.highlight {
    color: rgba(239, 240, 241, 0.5); }
  calendar:indeterminate:backdrop, calendar.highlight:backdrop {
    color: rgba(239, 240, 241, 0.5); }
  calendar:backdrop {
    color: #eff0f1;
    border-color: #616569;
    background-color: #232629; }

/*************************
 * Check and Radio items *
 *************************/
.view.content-view.check:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-selectionmode-unchecked.png"), url("../assets/check-selectionmode-unchecked@2.png"));
  background-color: transparent; }

.view.content-view.check:hover:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-selectionmode-unchecked-hover.png"), url("../assets/check-selectionmode-unchecked-hover@2.png"));
  background-color: transparent; }

.view.content-view.check:active:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-selectionmode-unchecked-active.png"), url("../assets/check-selectionmode-unchecked-active@2.png"));
  background-color: transparent; }

.view.content-view.check:backdrop:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-selectionmode-unchecked-backdrop.png"), url("../assets/check-selectionmode-unchecked-backdrop@2.png"));
  background-color: transparent; }

.view.content-view.check:checked:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-selectionmode-checked-active.png"), url("../assets/check-selectionmode-checked-active@2.png"));
  background-color: transparent; }

.view.content-view.check:checked:hover:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-selectionmode-checked-hover.png"), url("../assets/check-selectionmode-checked-hover@2.png"));
  background-color: transparent; }

.view.content-view.check:checked:active:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-selectionmode-checked-active.png"), url("../assets/check-selectionmode-checked-active@2.png"));
  background-color: transparent; }

.view.content-view.check:backdrop:checked:not(list) {
  -gtk-icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-selectionmode-checked-backdrop.png"), url("../assets/check-selectionmode-checked-backdrop@2.png"));
  background-color: transparent; }

checkbutton.text-button, radiobutton.text-button {
  padding: 2px 0;
  outline-offset: 0; }
  checkbutton.text-button label:not(:only-child):first-child, radiobutton.text-button label:not(:only-child):first-child {
    margin-left: 4px; }
  checkbutton.text-button label:not(:only-child):last-child, radiobutton.text-button label:not(:only-child):last-child {
    margin-right: 4px; }

check {
  margin: 0 4px;
  min-height: 18px;
  min-width: 18px;
  animation: none;
  background-color: transparent;
  -gtk-icon-source: -gtk-scaled(url("../assets/check-unchecked.png"), url("../assets/check-unchecked@2.png")); }
  check:only-child {
    margin: 0; }
  check:hover {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-unchecked-hover.png"), url("../assets/check-unchecked-hover@2.png")); }
  check:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-active.png"), url("../assets/check-checked-active@2.png")); }
    check:checked:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-hover.png"), url("../assets/check-checked-hover@2.png")); }
  check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-active.png"), url("../assets/check-mixed-active@2.png")); }
    check:indeterminate:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-hover.png"), url("../assets/check-mixed-hover@2.png")); }
  check:active {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-unchecked-active.png"), url("../assets/check-unchecked-active@2.png")); }
  check:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-active.png"), url("../assets/check-checked-active@2.png")); }
    check:checked:active {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-active.png"), url("../assets/check-checked-active@2.png")); }
  check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-active.png"), url("../assets/check-mixed-active@2.png")); }
    check:indeterminate:active {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-active.png"), url("../assets/check-mixed-active@2.png")); }
  check:disabled {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-unchecked-insensitive.png"), url("../assets/check-unchecked-insensitive@2.png")); }
  check:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-active.png"), url("../assets/check-checked-active@2.png")); }
    check:checked:disabled {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-insensitive.png"), url("../assets/check-checked-insensitive@2.png")); }
  check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-active.png"), url("../assets/check-mixed-active@2.png")); }
    check:indeterminate:disabled {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-insensitive.png"), url("../assets/check-mixed-insensitive@2.png")); }
  check:backdrop {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-unchecked-backdrop.png"), url("../assets/check-unchecked-backdrop@2.png")); }
  check:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-active.png"), url("../assets/check-checked-active@2.png")); }
    check:checked:backdrop {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-backdrop.png"), url("../assets/check-checked-backdrop@2.png")); }
  check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-active.png"), url("../assets/check-mixed-active@2.png")); }
    check:indeterminate:backdrop {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-backdrop.png"), url("../assets/check-mixed-backdrop@2.png")); }
  check:backdrop:disabled {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-unchecked-backdrop-insensitive.png"), url("../assets/check-unchecked-backdrop-insensitive@2.png")); }
  check:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-active.png"), url("../assets/check-checked-active@2.png")); }
    check:checked:backdrop:disabled {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-backdrop-insensitive.png"), url("../assets/check-checked-backdrop-insensitive@2.png")); }
  check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-active.png"), url("../assets/check-mixed-active@2.png")); }
    check:indeterminate:backdrop:disabled {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-backdrop-insensitive.png"), url("../assets/check-mixed-backdrop-insensitive@2.png")); }
  menu menuitem check {
    margin: 0;
    min-height: 18px;
    min-width: 18px;
    background-color: transparent;
    box-shadow: none;
    -gtk-icon-shadow: none;
    animation: none; }
    menu menuitem check:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-unchecked.png"), url("../assets/check-unchecked@2.png")); }
    menu menuitem check:checked:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-active.png"), url("../assets/check-checked-active@2.png")); }
    menu menuitem check:indeterminate:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed-active.png"), url("../assets/check-mixed-active@2.png")); }

radio {
  margin: 0 4px;
  min-height: 18px;
  min-width: 18px;
  animation: none;
  background-color: transparent;
  -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked.png"), url("../assets/radio-unchecked@2.png")); }
  radio:only-child {
    margin: 0; }
  radio:hover {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-hover.png"), url("../assets/radio-unchecked-hover@2.png")); }
  radio:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active.png"), url("../assets/radio-checked-active@2.png")); }
    radio:checked:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-hover.png"), url("../assets/radio-checked-hover@2.png")); }
  radio:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-active.png"), url("../assets/radio-mixed-active@2.png")); }
    radio:indeterminate:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-hover.png"), url("../assets/radio-mixed-hover@2.png")); }
  radio:active {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-active.png"), url("../assets/radio-unchecked-active@2.png")); }
  radio:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active.png"), url("../assets/radio-checked-active@2.png")); }
    radio:checked:active {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active.png"), url("../assets/radio-checked-active@2.png")); }
  radio:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-active.png"), url("../assets/radio-mixed-active@2.png")); }
    radio:indeterminate:active {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-active.png"), url("../assets/radio-mixed-active@2.png")); }
  radio:disabled {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-insensitive.png"), url("../assets/radio-unchecked-insensitive@2.png")); }
  radio:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active.png"), url("../assets/radio-checked-active@2.png")); }
    radio:checked:disabled {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-insensitive.png"), url("../assets/radio-checked-insensitive@2.png")); }
  radio:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-active.png"), url("../assets/radio-mixed-active@2.png")); }
    radio:indeterminate:disabled {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-insensitive.png"), url("../assets/radio-mixed-insensitive@2.png")); }
  radio:backdrop {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-backdrop.png"), url("../assets/radio-unchecked-backdrop@2.png")); }
  radio:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active.png"), url("../assets/radio-checked-active@2.png")); }
    radio:checked:backdrop {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-backdrop.png"), url("../assets/radio-checked-backdrop@2.png")); }
  radio:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-active.png"), url("../assets/radio-mixed-active@2.png")); }
    radio:indeterminate:backdrop {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-backdrop.png"), url("../assets/radio-mixed-backdrop@2.png")); }
  radio:backdrop:disabled {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked-backdrop-insensitive.png"), url("../assets/radio-unchecked-backdrop-insensitive@2.png")); }
  radio:checked {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active.png"), url("../assets/radio-checked-active@2.png")); }
    radio:checked:backdrop:disabled {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-backdrop-insensitive.png"), url("../assets/radio-checked-backdrop-insensitive@2.png")); }
  radio:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-active.png"), url("../assets/radio-mixed-active@2.png")); }
    radio:indeterminate:backdrop:disabled {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-backdrop-insensitive.png"), url("../assets/radio-mixed-backdrop-insensitive@2.png")); }
  menu menuitem radio {
    margin: 0;
    min-height: 18px;
    min-width: 18px;
    background-color: transparent;
    box-shadow: none;
    -gtk-icon-shadow: none;
    animation: none; }
    menu menuitem radio:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked.png"), url("../assets/radio-unchecked@2.png")); }
    menu menuitem radio:checked:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active.png"), url("../assets/radio-checked-active@2.png")); }
    menu menuitem radio:indeterminate:hover {
      -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed-active.png"), url("../assets/radio-mixed-active@2.png")); }

/*****************
 * Color Chooser *
 *****************/
:selected colorswatch {
  box-shadow: none; }
  :selected colorswatch.overlay, :selected colorswatch.overlay:hover {
    border-color: #eff0f1; }
colorswatch:selected {
  box-shadow: none; }
colorswatch.top, colorswatch.bottom, colorswatch.left, colorswatch:first-child:not(.overlay):not(.top), colorswatch.right, colorswatch:last-child:not(.overlay):not(.bottom), colorswatch:only-child:not(.overlay), colorswatch.top > .overlay, colorswatch.bottom > .overlay, colorswatch:first-child:not(.top) > .overlay, colorswatch:last-child:not(.bottom) > .overlay, colorswatch:only-child > .overlay {
  border-radius: 3px; }
colorswatch:hover, colorswatch:hover:selected {
  background-image: linear-gradient(135deg, rgba(255, 255, 255, 0.7), rgba(255, 255, 255, 0) 50%);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); }
  colorswatch:hover.color-dark, colorswatch:hover:selected.color-dark {
    background-image: linear-gradient(135deg, rgba(255, 255, 255, 0.5), rgba(255, 255, 255, 0) 50%); }
colorswatch:backdrop, colorswatch:backdrop:selected
colorswatch.color-dark:backdrop, colorswatch.color-dark:backdrop:selected {
  background-image: none;
  box-shadow: none; }
GtkColorEditor colorswatch {
  border-radius: 3px; }
  GtkColorEditor colorswatch:hover {
    background-image: none;
    box-shadow: none; }
  GtkColorEditor colorswatch:backdrop {
    box-shadow: none; }
colorswatch.color-dark {
  color: white;
  outline-color: rgba(0, 0, 0, 0.3); }
  colorswatch.color-dark:backdrop {
    color: rgba(255, 255, 255, 0.3); }
colorswatch.color-light {
  color: black;
  outline-color: rgba(255, 255, 255, 0.5); }
  colorswatch.color-light:backdrop {
    color: rgba(0, 0, 0, 0.3); }
colorswatch overlay,
colorswatch overlay:selected {
  border: 1px solid #616569; }
  colorswatch overlay:hover,
  colorswatch overlay:selected:hover {
    border-color: #3daee9; }
colorswatch#add-color-button {
  border-style: solid;
  border-width: 1px;
  box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.1);
  text-shadow: none;
  -gtk-icon-shadow: none;
  color: #eff0f1;
  border-color: #616569;
  background-image: linear-gradient(to bottom, #31373c, #303439); }
  colorswatch#add-color-button:hover {
    color: #eff0f1;
    border-color: #3daee9; }
  colorswatch#add-color-button:backdrop {
    color: #eff0f1;
    border-color: #616569;
    background-image: linear-gradient(to bottom, #31373c, #303439); }
  colorswatch#add-color-button overlay {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none; }

GtkColorButton.button {
  padding: 5px; }
  GtkColorButton.button GtkColorSwatch:first-child:last-child {
    border-radius: 0;
    box-shadow: none; }
    GtkColorButton.button GtkColorSwatch:first-child:last-child:disabled, GtkColorButton.button GtkColorSwatch:first-child:last-child:backdrop {
      box-shadow: none; }

/***********
 * Dialogs *
 ***********/
messagedialog.background {
  background-color: #31363b; }
messagedialog:backdrop {
  background-color: #31363b; }
messagedialog .titlebar {
  min-height: 32px;
  background-color: transparent;
  background-image: linear-gradient(to bottom, #3b4147, #31363b);
  box-shadow: none; }
messagedialog .dialog-action-area {
  padding: 8px; }
messagedialog button {
  margin: 2px; }

filechooser .search-bar {
  background-color: #31363b;
  border-color: #31363b;
  box-shadow: none; }
  filechooser .search-bar:backdrop {
    background-color: #31363b;
    border-color: #31363b;
    color: #eff0f1; }
filechooser .dialog-action-box {
  border-top: 1px solid #616569; }
  filechooser .dialog-action-box:backdrop {
    border-top-color: #616569; }
filechooser #pathbarbox {
  background-color: #31363b;
  border-bottom: 1px solid #616569; }

/***************
 * Header bars *
 ***************/
headerbar {
  transition: none;
  padding: 0px 6px;
  border-width: 0px 0px 1px 0px;
  border-radius: 3px 3px 0px 0px;
  border-style: solid;
  border-color: #3daee9;
  color: #eff0f1;
  background-image: linear-gradient(to bottom, #3b4147, #31363b); }
  headerbar:backdrop {
    border-color: transparent;
    background-image: none;
    background-color: #31363b;
    color: #7f8c8d;
    box-shadow: none; }
  headerbar label {
    font-weight: normal; }
    headerbar label:backdrop {
      color: #7f8c8d; }
  headerbar .path-bar button {
    color: #eff0f1;
    font-weight: normal; }
    headerbar .path-bar button:backdrop {
      color: #7f8c8d; }
  headerbar button {
    transition: none;
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none; }
    headerbar button.flat {
      border-color: rgba(255, 255, 255, 0);
      background-color: transparent;
      background-image: none;
      box-shadow: none;
      color: #eff0f1;
      text-shadow: none;
      -gtk-icon-shadow: none; }
    headerbar button:hover {
      color: #eff0f1;
      border-color: #3daee9; }
      headerbar button:hover:backdrop {
        border-color: #31363b; }
    headerbar button:active,
    headerbar button:checked {
      color: #eff0f1;
      border-color: #3daee9;
      background-image: linear-gradient(to bottom, #45b1ea, #25a4e6); }
      headerbar button:active:hover,
      headerbar button:checked:hover {
        color: #eff0f1;
        border-color: #3daee9;
        background-image: linear-gradient(to bottom, #45b1ea, #25a4e6); }
      headerbar button:active:backdrop,
      headerbar button:checked:backdrop {
        background-image: none;
        background-color: #31363b;
        border-color: #31363b;
        color: #7f8c8d; }
    headerbar button:backdrop {
      border-color: transparent;
      background-image: none;
      background-color: #31363b;
      color: #7f8c8d; }
    headerbar button.flat:backdrop,
    headerbar button.flat:backdrop:disabled,
    headerbar button:disabled:backdrop {
      background-image: none;
      background-color: #31363b;
      color: #7f8c8d;
      border-color: transparent; }
    headerbar button.flat:disabled {
      color: rgba(216, 218, 221, 0.35); }
    headerbar button:disabled {
      background-color: transparent;
      background-image: none;
      border-color: transparent;
      color: rgba(216, 218, 221, 0.35); }
      headerbar button:disabled:active,
      headerbar button:disabled:checked {
        color: rgba(216, 218, 221, 0.35);
        border-color: rgba(37, 164, 230, 0.35);
        background-image: linear-gradient(to bottom, rgba(44, 167, 231, 0.35), rgba(25, 152, 218, 0.35)); }
        headerbar button:disabled:active > .label,
        headerbar button:disabled:checked > .label {
          color: inherit; }
  headerbar .title {
    font-weight: normal;
    padding: 0px 12px; }
    headerbar .title:backdrop {
      color: #7f8c8d; }
  headerbar .subtitle {
    font-size: smaller;
    padding: 0 12px; }
    headerbar .subtitle:backdrop {
      color: #7f8c8d; }
  headerbar separator {
    border-width: 0px;
    background-color: transparent;
    background-image: none;
    border-color: transparent; }
  headerbar.selection-mode .selection-menu {
    padding: 4px 6px; }
    headerbar.selection-mode .selection-menu GtkArrow {
      -GtkArrow-arrow-scaling: 1; }
    headerbar.selection-mode .selection-menu .arrow {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
      -gtk-icon-shadow: none; }
  .tiled
  headerbar, .maximized
  headerbar {
    border-radius: 0; }

headerbar entry,
headerbar spinbutton,
headerbar separator,
headerbar button {
  margin-top: 3px;
  margin-bottom: 3px; }

headerbar button.suggested-action,
headerbar.selection-mode.suggested-action {
  background-image: none;
  background-color: #3daee9; }
  headerbar button.suggested-action:hover,
  headerbar.selection-mode.suggested-action:hover {
    background-color: #3daee9;
    color: #eff0f1; }
  headerbar button.suggested-action:disabled,
  headerbar.selection-mode.suggested-action:disabled {
    background-color: transparent;
    background-image: none;
    color: rgba(216, 218, 221, 0.35); }
    headerbar button.suggested-action:disabled:active,
    headerbar.selection-mode.suggested-action:disabled:active,
    headerbar button.suggested-action:disabled:checked,
    headerbar.selection-mode.suggested-action:disabled:checked {
      color: rgba(216, 218, 221, 0.35);
      border-color: rgba(37, 164, 230, 0.35);
      background-image: linear-gradient(to bottom, rgba(44, 167, 231, 0.35), rgba(25, 152, 218, 0.35)); }
      headerbar button.suggested-action:disabled:active > .label,
      headerbar.selection-mode.suggested-action:disabled:active > .label,
      headerbar button.suggested-action:disabled:checked > .label,
      headerbar.selection-mode.suggested-action:disabled:checked > .label {
        color: inherit; }
  headerbar button.suggested-action:backdrop,
  headerbar.selection-mode.suggested-action:backdrop {
    background-color: #31363b;
    border-color: transparent;
    color: #7f8c8d; }
    headerbar button.suggested-action:backdrop:disabled,
    headerbar.selection-mode.suggested-action:backdrop:disabled {
      color: rgba(115, 128, 129, 0.35); }

/**************
 * GtkInfoBar *
 **************/
infobar {
  border-style: none;
  border-bottom: 1px solid #616569;
  background-color: #31363b;
  background-image: none; }
  infobar:backdrop {
    border-bottom: 1px solid #616569; }

.info,
headerbar.selection-mode,
.question,
.warning,
.error {
  background-color: #31363b;
  background-image: none;
  color: #f67400;
  text-shadow: none; }
  .info:backdrop,
  headerbar.selection-mode:backdrop,
  .question:backdrop,
  .warning:backdrop,
  .error:backdrop {
    background-color: #31363b;
    color: #f67400; }
  .info button,
  headerbar.selection-mode button,
  .question button,
  .warning button,
  .error button {
    box-shadow: none;
    background-image: none;
    background-color: rgba(246, 116, 0, 0.5);
    border-color: rgba(246, 116, 0, 0.5);
    color: #eff0f1; }
    .info button:hover,
    headerbar.selection-mode button:hover,
    .question button:hover,
    .warning button:hover,
    .error button:hover {
      background-color: rgba(246, 116, 0, 0.25);
      border-color: #f67400; }
    .info button:active,
    headerbar.selection-mode button:active, .info button:checked,
    headerbar.selection-mode button:checked,
    .question button:active,
    .question button:checked,
    .warning button:active,
    .warning button:checked,
    .error button:active,
    .error button:checked {
      background-image: linear-gradient(to bottom, #f87500, #ef7100);
      color: #31363b;
      border-color: #f67400; }
    .info button:disabled,
    headerbar.selection-mode button:disabled,
    .question button:disabled,
    .warning button:disabled,
    .error button:disabled {
      background-color: rgba(224, 105, 0, 0);
      border-color: rgba(224, 105, 0, 0);
      color: rgba(216, 218, 221, 0.35); }
    .info button:backdrop,
    headerbar.selection-mode button:backdrop,
    .question button:backdrop,
    .warning button:backdrop,
    .error button:backdrop {
      background-color: rgba(246, 116, 0, 0.5);
      border-color: rgba(246, 116, 0, 0.5);
      color: #eff0f1; }
      .info button:backdrop:active,
      headerbar.selection-mode button:backdrop:active, .info button:backdrop:checked,
      headerbar.selection-mode button:backdrop:checked,
      .question button:backdrop:active,
      .question button:backdrop:checked,
      .warning button:backdrop:active,
      .warning button:backdrop:checked,
      .error button:backdrop:active,
      .error button:backdrop:checked {
        background-image: linear-gradient(to bottom, #f87500, #ef7100);
        color: #31363b;
        border-color: #f67400; }
      .info button:backdrop:disabled,
      headerbar.selection-mode button:backdrop:disabled,
      .question button:backdrop:disabled,
      .warning button:backdrop:disabled,
      .error button:backdrop:disabled {
        background-color: rgba(224, 105, 0, 0);
        border-color: rgba(224, 105, 0, 0);
        color: rgba(216, 218, 221, 0.35); }
      .info button:backdrop:disabled:active,
      headerbar.selection-mode button:backdrop:disabled:active, .info button:backdrop:disabled:checked,
      headerbar.selection-mode button:backdrop:disabled:checked,
      .question button:backdrop:disabled:active,
      .question button:backdrop:disabled:checked,
      .warning button:backdrop:disabled:active,
      .warning button:backdrop:disabled:checked,
      .error button:backdrop:disabled:active,
      .error button:backdrop:disabled:checked {
        background-image: linear-gradient(to bottom, rgba(226, 107, 0, 0.35), rgba(217, 102, 0, 0.35));
        color: #2d3136;
        border-color: rgba(224, 105, 0, 0.35); }

/*********
 * Links *
 *********/
button:link > label,
button:visited > label,
*:link,
button:link,
button:visited {
  color: #2980b9; }
  button:link > label:visited,
  button:visited > label:visited,
  *:link:visited,
  button:visited {
    color: #7f8c8d; }
    *:selected button:link > label:visited,
    *:selected button:visited > label:visited, *:selected
    *:link:visited, *:selected
    button:visited:link,
    *:selected button:visited {
      color: #a8d6ee; }
  button:link > label:hover,
  button:visited > label:hover,
  *:link:hover,
  button:hover:link,
  button:hover:visited {
    color: #409ad5; }
    *:selected button:link > label:hover,
    *:selected button:visited > label:hover, *:selected
    *:link:hover, *:selected
    button:hover:link,
    *:selected button:hover:visited {
      color: #dde9f0; }
  button:link > label:active,
  button:visited > label:active,
  *:link:active,
  button:active:link,
  button:active:visited {
    color: #2980b9; }
    *:selected button:link > label:active,
    *:selected button:visited > label:active, *:selected
    *:link:active, *:selected
    button:active:link,
    *:selected button:active:visited {
      color: #cbe3ef; }
  button:link > label:backdrop,
  button:visited > label:backdrop, button:link > label:backdrop:hover,
  button:visited > label:backdrop:hover, button:link > label:backdrop:hover:selected,
  button:visited > label:backdrop:hover:selected,
  *:link:backdrop,
  button:backdrop:link,
  button:backdrop:visited,
  *:link:backdrop:hover,
  button:backdrop:hover:link,
  button:backdrop:hover:visited,
  *:link:backdrop:hover:selected,
  headerbar.selection-mode .subtitle:backdrop:hover:link,
  button:backdrop:hover:selected:link,
  button:backdrop:hover:selected:visited {
    color: rgba(61, 174, 233, 0.5); }
  button:link > label:selected,
  button:visited > label:selected, *:selected button:link > label,
  *:selected button:visited > label,
  *:link:selected,
  headerbar.selection-mode .subtitle:link,
  button:selected:link,
  button:selected:visited, *:selected
  *:link, *:selected
  button:link,
  *:selected button:visited {
    color: #cbe3ef; }

button:link,
button:visited {
  text-shadow: none; }
  button:link:hover, button:link:active, button:link:checked,
  button:visited:hover,
  button:visited:active,
  button:visited:checked {
    text-shadow: none; }
  button:link > label,
  button:visited > label {
    text-decoration-line: underline; }

/*********
 * Lists *
 *********/
list {
  background-color: #31363b;
  color: #eff0f1;
  border-width: 0px; }
  list:backdrop {
    background-color: #31363b;
    color: #eff0f1; }
  list row {
    padding: 2px; }

row {
  transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }
  row:hover {
    transition: none; }
  row.activatable.has-open-popup, row.activatable:hover {
    background-color: rgba(61, 174, 233, 0.5); }
  row.activatable:active {
    box-shadow: none;
    background-color: #3daee9; }
  row.activatable:selected:active {
    box-shadow: none;
    background-color: #3daee9; }
  row.activatable:selected.has-open-popup, row.activatable:selected:hover {
    color: #eff0f1;
    background-color: #3daee9; }
  row.activatable:selected:backdrop {
    background-color: #3daee9; }

/*********
 * Menus *
 *********/
menubar,
.menubar {
  -GtkWidget-window-dragging: true;
  padding: 0px;
  box-shadow: none;
  border-style: none;
  background-color: #31363b; }
  menubar:backdrop,
  .menubar:backdrop {
    background-color: #31363b; }
  menubar > menuitem,
  .menubar > menuitem {
    min-height: 16px;
    padding: 4px 6px;
    border-style: solid;
    border-width: 1px 0px;
    border-color: #31363b; }
    menubar > menuitem:hover,
    .menubar > menuitem:hover {
      background-color: #3daee9;
      color: #eff0f1; }
    menubar > menuitem:disabled,
    .menubar > menuitem:disabled {
      color: rgba(216, 218, 221, 0.35);
      box-shadow: none; }
      menubar > menuitem:disabled:backdrop,
      .menubar > menuitem:disabled:backdrop {
        background-color: #31363b;
        color: rgba(216, 218, 221, 0.35); }
    menubar > menuitem:backdrop,
    .menubar > menuitem:backdrop {
      background-color: #31363b;
      border-color: #31363b;
      color: #eff0f1; }

menu,
.menu {
  padding: 0px;
  background-color: #31363b;
  border: 0px solid transparent;
  box-shadow: inset 0px 0px 0px 1px #616569;
  border-radius: 3px; }
  .csd menu, .csd
  .menu {
    border: 0px solid;
    border-radius: 3px; }
  menu separator,
  .menu separator {
    color: #616569;
    margin-top: 3px;
    margin-bottom: 3px; }
  menu menuitem,
  .menu menuitem {
    text-shadow: none;
    min-height: 16px;
    min-width: 40px;
    padding: 4px 4px; }
    menu menuitem:hover,
    .menu menuitem:hover {
      color: #eff0f1;
      background-color: #3daee9; }
    menu menuitem:disabled,
    .menu menuitem:disabled {
      color: rgba(216, 218, 221, 0.35); }
      menu menuitem:disabled:backdrop,
      .menu menuitem:disabled:backdrop {
        color: rgba(216, 218, 221, 0.35); }
    menu menuitem:backdrop, menu menuitem:backdrop:hover,
    .menu menuitem:backdrop,
    .menu menuitem:backdrop:hover {
      color: #eff0f1;
      background-color: #31363b; }
    menu menuitem arrow,
    .menu menuitem arrow {
      min-height: 16px;
      min-width: 16px; }
      menu menuitem arrow:dir(ltr),
      .menu menuitem arrow:dir(ltr) {
        -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
        margin-left: 10px; }
      menu menuitem arrow:dir(rtl),
      .menu menuitem arrow:dir(rtl) {
        -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
        margin-right: 10px; }
  menu > arrow,
  .menu > arrow {
    border-color: rgba(255, 255, 255, 0);
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    color: #eff0f1;
    text-shadow: none;
    -gtk-icon-shadow: none;
    min-height: 16px;
    min-width: 16px;
    padding: 4px;
    background-color: transparent;
    border-radius: 0; }
    menu > arrow.top,
    .menu > arrow.top {
      margin-top: -6px;
      border: none;
      -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
    menu > arrow.bottom,
    .menu > arrow.bottom {
      margin-bottom: -6px;
      border: none;
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
    menu > arrow:hover,
    .menu > arrow:hover {
      color: #3daee9; }
    menu > arrow:active,
    .menu > arrow:active {
      color: #3daee9; }
    menu > arrow:backdrop,
    .menu > arrow:backdrop {
      background-color: #31363b; }
    menu > arrow:disabled,
    .menu > arrow:disabled {
      color: transparent;
      background-color: transparent;
      border-color: transparent; }

menuitem accelerator {
  color: alpha(currentColor,0.55); }
menuitem check,
menuitem radio {
  min-height: 18px;
  min-width: 18px; }
  menuitem check:dir(ltr),
  menuitem radio:dir(ltr) {
    margin-right: 6px; }
  menuitem check:dir(rtl),
  menuitem radio:dir(rtl) {
    margin-left: 6px; }

/***************
 * Popovers   *
 ***************/
/* menu buttons */
modelbutton.flat, popover.background checkbutton,
popover.background radiobutton,
.menuitem.button.flat {
  min-height: 16px;
  padding: 4px 8px;
  color: #eff0f1; }
  modelbutton.flat:hover, popover.background checkbutton:hover,
  popover.background radiobutton:hover,
  .menuitem.button.flat:hover {
    background-color: #3daee9;
    color: #eff0f1; }
  modelbutton.flat:selected, popover.background checkbutton:selected,
  popover.background radiobutton:selected,
  .menuitem.button.flat:selected {
    background-color: #3daee9;
    color: #eff0f1; }
  modelbutton.flat:backdrop, popover.background checkbutton:backdrop,
  popover.background radiobutton:backdrop, modelbutton.flat:backdrop:hover, popover.background checkbutton:backdrop:hover,
  popover.background radiobutton:backdrop:hover,
  .menuitem.button.flat:backdrop,
  .menuitem.button.flat:backdrop:hover {
    color: #eff0f1; }
  modelbutton.flat check:hover, popover.background checkbutton check:hover,
  popover.background radiobutton check:hover,
  .menuitem.button.flat check:hover {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-unchecked.png"), url("../assets/check-unchecked@2.png")); }
  modelbutton.flat radio:hover, popover.background checkbutton radio:hover,
  popover.background radiobutton radio:hover,
  .menuitem.button.flat radio:hover {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-unchecked.png"), url("../assets/radio-unchecked@2.png")); }
  modelbutton.flat check:checked:hover, popover.background checkbutton check:checked:hover,
  popover.background radiobutton check:checked:hover,
  .menuitem.button.flat check:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-checked-active.png"), url("../assets/check-checked-active@2.png")); }
  modelbutton.flat radio:checked:hover, popover.background checkbutton radio:checked:hover,
  popover.background radiobutton radio:checked:hover,
  .menuitem.button.flat radio:checked:hover {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-checked-active.png"), url("../assets/radio-checked-active@2.png")); }
  modelbutton.flat check:indeterminate:hover, popover.background checkbutton check:indeterminate:hover,
  popover.background radiobutton check:indeterminate:hover,
  .menuitem.button.flat check:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("../assets/check-mixed.png"), url("../assets/check-mixed@2.png")); }
  modelbutton.flat radio:indeterminate:hover, popover.background checkbutton radio:indeterminate:hover,
  popover.background radiobutton radio:indeterminate:hover,
  .menuitem.button.flat radio:indeterminate:hover {
    -gtk-icon-source: -gtk-scaled(url("../assets/radio-mixed.png"), url("../assets/radio-mixed@2.png")); }
  modelbutton.flat check:last-child, popover.background checkbutton check:last-child,
  popover.background radiobutton check:last-child,
  modelbutton.flat radio:last-child,
  popover.background checkbutton radio:last-child,
  popover.background radiobutton radio:last-child,
  .menuitem.button.flat check:last-child,
  .menuitem.button.flat radio:last-child {
    margin-right: 0px; }
  modelbutton.flat check:first-child, popover.background checkbutton check:first-child,
  popover.background radiobutton check:first-child,
  modelbutton.flat radio:first-child,
  popover.background checkbutton radio:first-child,
  popover.background radiobutton radio:first-child,
  .menuitem.button.flat check:first-child,
  .menuitem.button.flat radio:first-child {
    margin-left: 0px; }

modelbutton.flat arrow, popover.background checkbutton arrow,
popover.background radiobutton arrow {
  background: none; }
  modelbutton.flat arrow:hover, popover.background checkbutton arrow:hover,
  popover.background radiobutton arrow:hover {
    background: none; }
  modelbutton.flat arrow.left, popover.background checkbutton arrow.left,
  popover.background radiobutton arrow.left {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
  modelbutton.flat arrow.right, popover.background checkbutton arrow.right,
  popover.background radiobutton arrow.right {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

popover.background {
  margin: -10px;
  padding: 0px;
  border: 1px solid #616569;
  border-radius: 3px;
  background-color: #31363b;
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.9); }
  popover.background:backdrop {
    box-shadow: none; }
  popover.background > list,
  popover.background > .view,
  popover.background > toolbar {
    border-style: none;
    background-color: transparent; }
  .csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier {
    border: 1px solid #616569; }
  popover.background separator {
    margin: 3px; }
  popover.background list separator {
    margin: 0px; }

GtkVolumeButton.button {
  padding: 5px; }

/********
 * Misc *
 ********/
/****************
* Print dialog *
*****************/
printdialog paper {
  color: #eff0f1;
  border: 1px solid #616569;
  background: white;
  padding: 0; }
  printdialog paper:backdrop {
    color: #eff0f1;
    border-color: #616569;
    background: white; }
printdialog .dialog-action-box {
  margin: 12px; }

/**********
* Frames *
**********/
frame > border,
.frame {
  box-shadow: none;
  margin: 0;
  padding: 0;
  border-radius: 0;
  border: 1px solid #616569; }
  frame > border.flat,
  .frame.flat {
    border-style: none; }
  frame > border:backdrop,
  .frame:backdrop {
    border-color: #616569; }

actionbar > revealer > box {
  padding: 6px;
  border-top: 1px solid #616569; }
  actionbar > revealer > box:backdrop {
    border-color: #616569; }

scrolledwindow viewport.frame {
  border-style: none; }
scrolledwindow junction {
  border-color: transparent;
  background-color: transparent;
  background-image: none; }

separator {
  background: #616569;
  min-width: 1px;
  min-height: 1px; }

/*************
* Expanders *
*************/
expander arrow {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
  expander arrow:dir(rtl) {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
  expander arrow:hover {
    color: white; }
  expander arrow:checked {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

/*********
* Paned *
*********/
paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: image(#616569);
  background-size: 1px 1px; }
  paned > separator:backdrop {
    background-image: image(#616569); }
  paned > separator.wide {
    min-width: 5px;
    min-height: 5px;
    background-color: #31363b;
    background-image: image(#616569), image(#616569);
    background-size: 1px 1px, 1px 1px; }
    paned > separator.wide:backdrop {
      background-color: #31363b;
      background-image: image(#616569), image(#616569); }
paned.horizontal > separator {
  background-repeat: repeat-y; }
  paned.horizontal > separator:dir(ltr) {
    margin: 0 -8px 0 0;
    padding: 0 8px 0 0;
    background-position: left; }
  paned.horizontal > separator:dir(rtl) {
    margin: 0 0 0 -8px;
    padding: 0 0 0 8px;
    background-position: right; }
  paned.horizontal > separator.wide {
    margin: 0;
    padding: 0;
    background-repeat: repeat-y, repeat-y;
    background-position: left, right; }
paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top; }
  paned.vertical > separator.wide {
    margin: 0;
    padding: 0;
    background-repeat: repeat-x, repeat-x;
    background-position: bottom, top; }

/*********************
* Spinner Animation *
*********************/
@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn); } }
spinner {
  background-image: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }
  spinner:checked {
    opacity: 1;
    animation: spin 1s linear infinite; }
    spinner:checked:disabled {
      opacity: 0.5; }

/*****************
 * Notebooks and *
 * Tabs          *
 *****************/
/*************
 * Notebooks *
 *************/
notebook.frame {
  border: none;
  padding: 0px;
  box-shadow: inset 0px 0px 0px 1px #616569; }
notebook > header {
  padding: 0px;
  border: none;
  background-color: #31363b; }
  notebook > header.top {
    box-shadow: inset 0 -1px #616569; }
    notebook > header.top:backdrop {
      box-shadow: inset 0 -1px #616569; }
  notebook > header.bottom {
    box-shadow: inset 0 1px #616569; }
    notebook > header.bottom:backdrop {
      box-shadow: inset 0 1px #616569; }
  notebook > header.right {
    box-shadow: inset 1px 0 #616569; }
    notebook > header.right:backdrop {
      box-shadow: inset 1px 0 #616569; }
  notebook > header.left {
    box-shadow: inset -1px 0 #616569; }
    notebook > header.left:backdrop {
      box-shadow: inset -1px 0 #616569; }
  notebook > header:backdrop {
    background-color: #31363b; }
  notebook > header tabs {
    margin: 0px; }
  notebook > header.top > tabs > tab {
    padding: 4px 6px;
    border: 1px solid rgba(239, 240, 241, 0.2);
    background-color: rgba(239, 240, 241, 0.2);
    border-radius: 3px 3px 0px 0px;
    border-bottom-color: transparent; }
    notebook > header.top > tabs > tab:hover, notebook > header.top > tabs > tab.prelight-page {
      background-color: rgba(61, 174, 233, 0.2);
      border-color: rgba(61, 174, 233, 0.2); }
    notebook > header.top > tabs > tab:checked {
      border-color: #616569;
      border-bottom-color: #31363b;
      background-color: #31363b; }
      notebook > header.top > tabs > tab:checked:backdrop {
        border-color: #616569;
        border-bottom-color: #31363b;
        background-color: #31363b; }
  notebook > header.bottom > tabs > tab {
    padding: 4px 6px;
    border: 1px solid rgba(239, 240, 241, 0.2);
    background-color: rgba(239, 240, 241, 0.2);
    border-radius: 0px 0px 3px 3px;
    border-top-color: transparent; }
    notebook > header.bottom > tabs > tab:hover, notebook > header.bottom > tabs > tab.prelight-page {
      background-color: rgba(61, 174, 233, 0.2);
      border-color: rgba(61, 174, 233, 0.2); }
    notebook > header.bottom > tabs > tab:checked {
      border-color: #616569;
      border-top-color: #31363b;
      background-color: #31363b; }
      notebook > header.bottom > tabs > tab:checked:backdrop {
        border-color: #616569;
        border-top-color: #31363b;
        background-color: #31363b; }
  notebook > header.left > tabs > tab {
    padding: 4px 6px;
    border: 1px solid rgba(239, 240, 241, 0.2);
    background-color: rgba(239, 240, 241, 0.2);
    border-radius: 3px 0px 0px 3px;
    border-right-color: transparent; }
    notebook > header.left > tabs > tab:hover, notebook > header.left > tabs > tab.prelight-page {
      background-color: rgba(61, 174, 233, 0.2);
      border-color: rgba(61, 174, 233, 0.2); }
    notebook > header.left > tabs > tab:checked {
      border-color: #616569;
      border-right-color: #31363b;
      background-color: #31363b; }
      notebook > header.left > tabs > tab:checked:backdrop {
        border-color: #616569;
        border-right-color: #31363b;
        background-color: #31363b; }
  notebook > header.right > tabs > tab {
    padding: 4px 6px;
    border: 1px solid rgba(239, 240, 241, 0.2);
    background-color: rgba(239, 240, 241, 0.2);
    border-radius: 0px 3px 3px 0px;
    border-left-color: transparent; }
    notebook > header.right > tabs > tab:hover, notebook > header.right > tabs > tab.prelight-page {
      background-color: rgba(61, 174, 233, 0.2);
      border-color: rgba(61, 174, 233, 0.2); }
    notebook > header.right > tabs > tab:checked {
      border-color: #616569;
      border-left-color: #31363b;
      background-color: #31363b; }
      notebook > header.right > tabs > tab:checked:backdrop {
        border-color: #616569;
        border-left-color: #31363b;
        background-color: #31363b; }
  notebook > header.top > tabs > tab.reorderable-page {
    border-width: 3px;
    border-style: solid;
    border-color: transparent;
    background-color: #31363b;
    background-clip: padding-box;
    border-right-width: 1px;
    border-right-color: #616569;
    box-shadow: inset -3px 0px 0px 0px #31363b; }
    notebook > header.top > tabs > tab.reorderable-page:hover, notebook > header.top > tabs > tab.reorderable-page.prelight-page {
      box-shadow: inset 0px -3px 0px 0px rgba(61, 174, 233, 0.2), inset -3px 0px 0px 0px #31363b; }
    notebook > header.top > tabs > tab.reorderable-page:checked {
      box-shadow: inset 0px -3px 0px 0px #3daee9, inset -3px 0px 0px 0px #31363b; }
      notebook > header.top > tabs > tab.reorderable-page:checked:backdrop {
        background-color: #31363b;
        border-color: transparent;
        border-right-color: #616569;
        box-shadow: none; }
    notebook > header.top > tabs > tab.reorderable-page:backdrop {
      background-color: #31363b;
      border-right-color: #616569;
      box-shadow: none; }
  notebook > header.bottom > tabs > tab.reorderable-page {
    border-width: 3px;
    border-style: solid;
    border-color: transparent;
    background-color: #31363b;
    background-clip: padding-box;
    border-right-width: 1px;
    border-right-color: #616569;
    box-shadow: inset -3px 0px 0px 0px #31363b; }
    notebook > header.bottom > tabs > tab.reorderable-page:hover, notebook > header.bottom > tabs > tab.reorderable-page.prelight-page {
      box-shadow: inset 0px -3px 0px 0px rgba(61, 174, 233, 0.2), inset -3px 0px 0px 0px #31363b; }
    notebook > header.bottom > tabs > tab.reorderable-page:checked {
      box-shadow: inset 0px -3px 0px 0px #3daee9, inset -3px 0px 0px 0px #31363b; }
      notebook > header.bottom > tabs > tab.reorderable-page:checked:backdrop {
        background-color: #31363b;
        border-color: transparent;
        border-right-color: #616569;
        box-shadow: none; }
    notebook > header.bottom > tabs > tab.reorderable-page:backdrop {
      background-color: #31363b;
      border-right-color: #616569;
      box-shadow: none; }
  notebook > header.left > tabs > tab.reorderable-page {
    border-width: 3px;
    border-style: solid;
    border-color: transparent;
    background-color: #31363b;
    background-clip: padding-box;
    border-bottom-width: 1px;
    border-bottom-color: #616569;
    box-shadow: inset 0px -3px 0px 0px #31363b; }
    notebook > header.left > tabs > tab.reorderable-page:hover, notebook > header.left > tabs > tab.reorderable-page.prelight-page {
      box-shadow: inset 0px -3px 0px 0px rgba(61, 174, 233, 0.2), inset 0px -3px 0px 0px #31363b; }
    notebook > header.left > tabs > tab.reorderable-page:checked {
      box-shadow: inset 0px -3px 0px 0px #3daee9, inset 0px -3px 0px 0px #31363b; }
      notebook > header.left > tabs > tab.reorderable-page:checked:backdrop {
        background-color: #31363b;
        border-color: transparent;
        border-bottom-color: #616569;
        box-shadow: none; }
    notebook > header.left > tabs > tab.reorderable-page:backdrop {
      background-color: #31363b;
      border-bottom-color: #616569;
      box-shadow: none; }
  notebook > header.right > tabs > tab.reorderable-page {
    border-width: 3px;
    border-style: solid;
    border-color: transparent;
    background-color: #31363b;
    background-clip: padding-box;
    border-bottom-width: 1px;
    border-bottom-color: #616569;
    box-shadow: inset 0px -3px 0px 0px #31363b; }
    notebook > header.right > tabs > tab.reorderable-page:hover, notebook > header.right > tabs > tab.reorderable-page.prelight-page {
      box-shadow: inset 0px -3px 0px 0px rgba(61, 174, 233, 0.2), inset 0px -3px 0px 0px #31363b; }
    notebook > header.right > tabs > tab.reorderable-page:checked {
      box-shadow: inset 0px -3px 0px 0px #3daee9, inset 0px -3px 0px 0px #31363b; }
      notebook > header.right > tabs > tab.reorderable-page:checked:backdrop {
        background-color: #31363b;
        border-color: transparent;
        border-bottom-color: #616569;
        box-shadow: none; }
    notebook > header.right > tabs > tab.reorderable-page:backdrop {
      background-color: #31363b;
      border-bottom-color: #616569;
      box-shadow: none; }
  notebook > header.top > tabs > arrow {
    border-top-style: none; }
  notebook > header.bottom > tabs > arrow {
    border-bottom-style: none; }
  notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow {
    margin-left: -5px;
    margin-right: -5px;
    padding-left: 4px;
    padding-right: 4px; }
    notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
      -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
    notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
      -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
  notebook > header.left > tabs > arrow {
    border-left-style: none; }
  notebook > header.right > tabs > arrow {
    border-right-style: none; }
  notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow {
    margin-top: -5px;
    margin-bottom: -5px;
    padding-top: 4px;
    padding-bottom: 4px; }
    notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
      -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
    notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
  notebook > header > tabs > arrow {
    min-height: 16px;
    min-width: 16px;
    border-radius: 0; }
    notebook > header > tabs > arrow:hover:not(:active):not(:backdrop) {
      background-clip: padding-box;
      background-image: none;
      background-color: rgba(255, 255, 255, 0.3);
      border-color: transparent;
      box-shadow: none; }
    notebook > header > tabs > arrow:disabled {
      border-color: rgba(255, 255, 255, 0);
      background-color: transparent;
      background-image: none;
      box-shadow: none;
      color: #eff0f1;
      text-shadow: none;
      -gtk-icon-shadow: none; }
  notebook > header button.flat {
    padding: 0;
    margin: 4px;
    min-width: 12px;
    min-height: 12px;
    border: 0px solid;
    border-radius: 50%;
    color: #31363b;
    background-color: #616569;
    background-image: none; }
    notebook > header button.flat:hover {
      background-color: #da4453; }
    notebook > header button.flat:active {
      background-color: #da4453; }
    notebook > header button.flat:backdrop {
      background-color: #616569;
      color: #31363b; }
notebook > stack:not(:only-child) {
  background-color: transparent;
  border-style: solid;
  border-color: #616569;
  border-width: 0px; }

scrolledwindow overshoot.top {
  background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(#494c4e), to(rgba(73, 76, 78, 0))), -gtk-gradient(radial, center top, 0, center top, 0.6, from(rgba(239, 240, 241, 0.07)), to(rgba(239, 240, 241, 0)));
  background-size: 100% 5%, 100% 100%;
  background-repeat: no-repeat;
  background-position: center top;
  background-color: transparent;
  border: none;
  box-shadow: none; }
  scrolledwindow overshoot.top:backdrop {
    background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(#616569), to(rgba(97, 101, 105, 0)));
    background-size: 100% 5%;
    background-repeat: no-repeat;
    background-position: center top;
    background-color: transparent;
    border: none;
    box-shadow: none; }
scrolledwindow overshoot.bottom {
  background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(#494c4e), to(rgba(73, 76, 78, 0))), -gtk-gradient(radial, center bottom, 0, center bottom, 0.6, from(rgba(239, 240, 241, 0.07)), to(rgba(239, 240, 241, 0)));
  background-size: 100% 5%, 100% 100%;
  background-repeat: no-repeat;
  background-position: center bottom;
  background-color: transparent;
  border: none;
  box-shadow: none; }
  scrolledwindow overshoot.bottom:backdrop {
    background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(#616569), to(rgba(97, 101, 105, 0)));
    background-size: 100% 5%;
    background-repeat: no-repeat;
    background-position: center bottom;
    background-color: transparent;
    border: none;
    box-shadow: none; }
scrolledwindow overshoot.left {
  background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(#494c4e), to(rgba(73, 76, 78, 0))), -gtk-gradient(radial, left center, 0, left center, 0.6, from(rgba(239, 240, 241, 0.07)), to(rgba(239, 240, 241, 0)));
  background-size: 5% 100%, 100% 100%;
  background-repeat: no-repeat;
  background-position: left center;
  background-color: transparent;
  border: none;
  box-shadow: none; }
  scrolledwindow overshoot.left:backdrop {
    background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(#616569), to(rgba(97, 101, 105, 0)));
    background-size: 5% 100%;
    background-repeat: no-repeat;
    background-position: left center;
    background-color: transparent;
    border: none;
    box-shadow: none; }
scrolledwindow overshoot.right {
  background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(#494c4e), to(rgba(73, 76, 78, 0))), -gtk-gradient(radial, right center, 0, right center, 0.6, from(rgba(239, 240, 241, 0.07)), to(rgba(239, 240, 241, 0)));
  background-size: 5% 100%, 100% 100%;
  background-repeat: no-repeat;
  background-position: right center;
  background-color: transparent;
  border: none;
  box-shadow: none; }
  scrolledwindow overshoot.right:backdrop {
    background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(#616569), to(rgba(97, 101, 105, 0)));
    background-size: 5% 100%;
    background-repeat: no-repeat;
    background-position: right center;
    background-color: transparent;
    border: none;
    box-shadow: none; }
scrolledwindow undershoot {
  background-image: none;
  border: none; }

/************
 * Pathbars *
 ************/
.path-bar {
  background-color: #31363b;
  border-bottom: 1px solid #616569; }

.path-bar button {
  border-color: rgba(255, 255, 255, 0);
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  color: #eff0f1;
  text-shadow: none;
  -gtk-icon-shadow: none;
  padding: 4px 8px;
  color: #eff0f1; }
  .path-bar button:hover {
    border-color: #3daee9; }
  .path-bar button:active, .path-bar button:checked {
    background-color: #616569;
    font-weight: normal; }
  .path-bar button.text-button, .path-bar button.image-button, .path-bar button {
    padding-left: 4px;
    padding-right: 4px; }
  .path-bar button.text-button.image-button label {
    padding-left: 0;
    padding-right: 0; }
  .path-bar button.text-button.image-button label:last-child, .path-bar button label:last-child {
    padding-right: 8px; }
  .path-bar button.text-button.image-button label:first-child, .path-bar button label:first-child {
    padding-left: 8px; }
  .path-bar button image {
    padding-left: 4px;
    padding-right: 4px; }
  .path-bar button.slider-button {
    padding-left: 0;
    padding-right: 0; }

/*****************
 * Progress bars *
 *****************/
progressbar {
  font-size: smaller;
  color: rgba(239, 240, 241, 0.3); }
  progressbar.horizontal trough,
  progressbar.horizontal progress {
    min-height: 6px; }
  progressbar.vertical trough,
  progressbar.vertical progress {
    min-width: 6px; }
  progressbar trough {
    border: 0px solid transparent;
    border-radius: 3px;
    background-color: rgba(239, 240, 241, 0.3); }
  progressbar:backdrop trough {
    background-color: rgba(239, 240, 241, 0.3); }
  progressbar progress {
    background-color: #3daee9;
    border: 0px solid transparent;
    border-radius: 3px;
    box-shadow: none; }
  progressbar:backdrop progress {
    background-color: #3daee9; }
  progressbar.osd {
    background-color: transparent; }

treeview.view.progressbar {
  border: 0px solid transparent;
  border-radius: 3px;
  background-color: #3daee9;
  color: #eff0f1;
  background-image: none; }
  treeview.view.progressbar:selected:focus, treeview.view.progressbar:selected {
    background-color: rgba(239, 240, 241, 0.25); }
treeview.view.trough {
  background-color: #6a6e72; }
  treeview.view.trough:selected:focus, treeview.view.trough:selected {
    background-color: rgba(239, 240, 241, 0.3); }

/*************
 * Level Bar *
 *************/
levelbar block {
  min-width: 32px;
  min-height: 6px; }
levelbar.vertical block {
  min-width: 6px;
  min-height: 32px; }
levelbar trough {
  border: 1px solid;
  padding: 2px;
  border-radius: 3px;
  color: #eff0f1;
  border-color: #616569;
  background-color: #232629;
  box-shadow: none; }
  levelbar trough:backdrop {
    color: #eff0f1;
    border-color: #616569;
    background-color: #232629; }
levelbar.horizontal.discrete block {
  margin: 0 1px; }
levelbar.vertical.discrete block {
  margin: 1px 0; }
levelbar block:not(.empty) {
  border: 1px solid #3daee9;
  background-color: #3daee9;
  box-shadow: none;
  border-radius: 1px; }
  levelbar block:not(.empty):backdrop {
    border-color: #3daee9;
    background-color: #3daee9; }
levelbar block.low {
  border-color: #f67400;
  background-color: #f67400; }
  levelbar block.low:backdrop {
    background-color: #f67400;
    border-color: #f67400; }
levelbar block.high {
  border-color: #27ae60;
  background-color: #27ae60; }
  levelbar block.high:backdrop {
    background-color: #27ae60;
    border-color: #27ae60; }
levelbar block.full {
  border-color: #27ae60;
  background-color: #27ae60; }
  levelbar block.full:backdrop {
    background-color: #27ae60;
    border-color: #27ae60; }
levelbar block.empty {
  background-color: rgba(239, 240, 241, 0.3);
  border-color: transparent;
  box-shadow: none; }
  levelbar block.empty:backdrop {
    background-color: rgba(239, 240, 241, 0.3); }

/************
 * GtkScale *
 ************/
scale.fine-tune.trough {
  margin: 8px;
  border-radius: 3px; }
scale slider {
  min-width: 18px;
  min-height: 18px;
  background-color: #31363b;
  border: 1px solid #616569;
  border-radius: 50%;
  box-shadow: none;
  margin: -9px; }
  scale slider:hover {
    border-style: solid;
    border-width: 2px;
    border-color: #3daee9;
    border-radius: 50%; }
    scale slider:hover:backdrop {
      background-color: #31363b;
      border-color: #3daee9; }
  scale slider:disabled {
    border-style: solid;
    border-radius: 50%;
    background-color: #31363b;
    border-color: rgba(88, 92, 95, 0.35); }
    scale slider:disabled:backdrop {
      background-color: #31363b;
      border-color: rgba(88, 92, 95, 0.35); }
  scale slider:active {
    border: 2px solid #3daee9; }
    scale slider:active:backdrop {
      background-color: #31363b;
      border-color: #3daee9; }
  scale slider:backdrop {
    background-color: #31363b;
    border-color: #616569; }
scale trough {
  min-width: 6px;
  min-height: 6px;
  margin: 9px;
  border: 0px solid;
  border-radius: 3px;
  background-color: #6a6e72;
  box-shadow: none; }
  scale trough:disabled, scale trough.vertical:disabled {
    border-color: rgba(96, 100, 104, 0.35);
    background-color: rgba(96, 100, 104, 0.35);
    box-shadow: none; }
    scale trough:disabled:backdrop, scale trough.vertical:disabled:backdrop {
      background-color: rgba(96, 100, 104, 0.35);
      border-color: rgba(96, 100, 104, 0.35); }
  scale trough:backdrop {
    background-color: #6a6e72;
    border-color: #6a6e72; }
scale highlight {
  border: 0px solid;
  border-radius: 3px;
  background-color: #3daee9;
  border-color: #3daee9; }
  scale highlight.vertical {
    background-color: #3daee9;
    border-color: #3daee9; }
  scale highlight:disabled {
    background-color: rgba(37, 164, 230, 0.35); }
  scale highlight:backdrop {
    background-color: rgba(61, 174, 233, 0.5);
    border-color: rgba(61, 174, 233, 0.5); }
    scale highlight:backdrop:disabled {
      background-color: rgba(37, 164, 230, 0.35); }

/**************
 * Scrollbars *
 **************/
scrollbar {
  -GtkScrollbar-has-backward-stepper: true;
  -GtkScrollbar-has-forward-stepper: true;
  background-color: #31363b;
  border-width: 3px 0px;
  border-color: #31363b;
  margin: 0px; }
  scrollbar button {
    min-width: 14px;
    min-height: 14px;
    margin: 0px;
    padding: 0px 3px;
    border: none;
    border-radius: 0px;
    background-image: none;
    background-color: #31363b;
    color: #eff0f1;
    box-shadow: none; }
    scrollbar button:hover {
      border: none;
      background-image: none;
      background-color: #31363b;
      color: #3daee9; }
    scrollbar button:active, scrollbar button:active:hover {
      border: none;
      background-image: none;
      background-color: #31363b;
      color: #3daee9; }
    scrollbar button:disabled {
      border: none;
      background-color: #31363b;
      background-image: none;
      color: rgba(216, 218, 221, 0.35); }
    scrollbar button:backdrop {
      color: #eff0f1; }
      scrollbar button:backdrop:disabled {
        color: rgba(216, 218, 221, 0.35); }
  scrollbar.dragging, scrollbar.hovering {
    opacity: 0.9910; }
  scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
    opacity: 0.999; }
  scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
    -GtkScrollbar-has-backward-stepper: false;
    -GtkScrollbar-has-forward-stepper: false;
    background: none; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
      min-width: 4px;
      margin: 2px;
      border: none;
      border-radius: 2px;
      background-color: #adafb2; }
      scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider:backdrop {
        background-color: #adafb2; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering) trough {
      min-width: 4px;
      min-height: 4px;
      border: none;
      background: none;
      box-shadow: none; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
      min-height: 4px; }
  scrollbar trough {
    min-width: 16px;
    min-height: 16px;
    border: 0px solid transparent;
    border-radius: 8px;
    background-color: #6a6e72;
    box-shadow: inset 0px 0px 0px 3px #31363b; }
  scrollbar slider {
    min-width: 10px;
    min-height: 30px;
    border: 2px solid transparent;
    border-radius: 8px;
    background-clip: padding-box;
    background-color: #adafb2; }
    scrollbar slider:hover {
      background-color: #3daee9; }
    scrollbar slider:active {
      background-color: #3daee9; }
    scrollbar slider:disabled {
      background-color: rgba(157, 159, 163, 0.35); }
    scrollbar slider:backdrop {
      background-color: #adafb2; }
    scrollbar slider:backdrop:disabled {
      background-color: rgba(157, 159, 163, 0.35); }
  scrollbar.horizontal slider {
    min-width: 30px;
    min-height: 10px; }
  scrollbar.vertical button.down {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
  scrollbar.vertical button.up {
    -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
  scrollbar.horizontal button.down {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
  scrollbar.horizontal button.up {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

/***********
 * Sidebar *
 ***********/
.sidebar {
  border: none;
  background-color: #31363b; }
  .sidebar:backdrop {
    background-color: #31363b; }

placessidebar > viewport.frame {
  border-style: none; }
placessidebar row {
  min-height: 36px;
  padding: 0px; }
  placessidebar row > revealer {
    padding: 0 14px; }
  placessidebar row:selected {
    color: #eff0f1; }
  placessidebar row:disabled {
    color: rgba(216, 218, 221, 0.35); }
  placessidebar row:backdrop {
    color: #eff0f1; }
    placessidebar row:backdrop:selected {
      color: #3daee9; }
    placessidebar row:backdrop:disabled {
      color: rgba(216, 218, 221, 0.35); }
  placessidebar row image.sidebar-icon:dir(ltr) {
    padding-right: 8px; }
  placessidebar row image.sidebar-icon:dir(rtl) {
    padding-left: 8px; }
  placessidebar row label.sidebar-label:dir(ltr) {
    padding-right: 2px; }
  placessidebar row label.sidebar-label:dir(rtl) {
    padding-left: 2px; }
  button.sidebar-button {
    min-height: 26px;
    min-width: 26px;
    margin-top: 3px;
    margin-bottom: 3px;
    padding: 0; }
  placessidebar row:selected:active {
    box-shadow: none; }
  placessidebar row.sidebar-placeholder-row {
    padding: 0 8px;
    min-height: 2px;
    background-image: none;
    background-clip: content-box; }
  placessidebar row.sidebar-new-bookmark-row {
    color: #3daee9; }

placesview .server-list-button > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(0turn); }
placesview .server-list-button:checked > image {
  transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
  -gtk-icon-transform: rotate(-0.5turn); }
placesview row.activatable:hover {
  background-color: transparent; }
placesview > actionbar > revealer > box > label {
  padding-left: 8px;
  padding-right: 8px; }

stacksidebar.sidebar row {
  padding: 10px 4px; }
  stacksidebar.sidebar row > label {
    padding-left: 6px;
    padding-right: 6px; }
  stacksidebar.sidebar row.needs-attention > .label {
    background-size: 6px 6px, 0 0; }

/*****************
 * GtkSpinButton *
 *****************/
spinbutton:not(.vertical) {
  padding: 0; }
  spinbutton:not(.vertical) entry {
    min-width: 28px;
    margin: 0;
    background: none;
    background-color: transparent;
    border: none;
    border-radius: 0;
    box-shadow: none; }
    spinbutton:not(.vertical) entry:backdrop:disabled {
      background-color: transparent; }
  spinbutton:not(.vertical) button {
    min-height: 16px;
    margin: 0;
    padding-bottom: 0;
    padding-top: 0;
    color: #eff0f1;
    background-image: none;
    background-color: transparent;
    border-style: none;
    box-shadow: none; }
    spinbutton:not(.vertical) button:hover {
      color: #3daee9; }
    spinbutton:not(.vertical) button:disabled {
      color: rgba(216, 218, 221, 0.35); }
    spinbutton:not(.vertical) button:active {
      color: #3daee9;
      box-shadow: none; }
    spinbutton:not(.vertical) button:backdrop {
      color: #eff0f1;
      background-color: transparent; }
    spinbutton:not(.vertical) button:backdrop:disabled {
      color: rgba(216, 218, 221, 0.35);
      background-color: transparent;
      border-style: none; }
    spinbutton:not(.vertical) button:dir(ltr):last-child {
      border-radius: 0 3px 3px 0; }
    spinbutton:not(.vertical) button:dir(rtl):first-child {
      border-radius: 3px 0 0 3px; }
spinbutton.vertical:disabled {
  color: rgba(216, 218, 221, 0.35); }
spinbutton.vertical:backdrop:disabled {
  color: rgba(216, 218, 221, 0.35); }
spinbutton.vertical:drop(active) {
  border-color: transparent;
  box-shadow: none; }
spinbutton.vertical entry {
  margin: 0px;
  min-height: 26px;
  min-width: 26px;
  border-style: none solid none solid;
  border-color: #616569;
  padding: 0;
  border-radius: 0; }
  spinbutton.vertical entry:disabled {
    color: rgba(216, 218, 221, 0.35);
    background-color: #202325;
    border-color: rgba(88, 92, 95, 0.35); }
  spinbutton.vertical entry:backdrop:disabled {
    color: rgba(216, 218, 221, 0.35);
    background-color: #202325;
    border-color: rgba(88, 92, 95, 0.35); }
spinbutton.vertical button {
  min-height: 26px;
  min-width: 26px;
  padding: 0;
  box-shadow: none;
  background-image: none;
  background-color: #232629;
  color: #eff0f1;
  border-color: #616569; }
  spinbutton.vertical button:hover {
    color: #3daee9; }
  spinbutton.vertical button:active {
    color: #3daee9; }
  spinbutton.vertical button:disabled {
    color: rgba(216, 218, 221, 0.35);
    background-color: #202325;
    border-color: rgba(88, 92, 95, 0.35); }
  spinbutton.vertical button:backdrop:disabled {
    color: rgba(216, 218, 221, 0.35);
    background-color: #202325;
    border-color: rgba(88, 92, 95, 0.35); }
spinbutton.vertical button.up {
  border-radius: 3px 3px 0 0;
  border-style: solid solid none solid; }
spinbutton.vertical button.down {
  border-radius: 0 0 3px 3px;
  border-style: none solid solid solid; }
treeview spinbutton:not(.vertical) {
  min-height: 0;
  border-style: none;
  border-radius: 0; }
  treeview spinbutton:not(.vertical) entry {
    min-height: 0;
    padding: 1px 2px; }

/**********
 * Switch *
 **********/
switch {
  margin: 2px;
  font-weight: bold;
  font-size: smaller;
  min-width: 48px;
  min-height: 24px;
  border: 0px solid;
  border-radius: 12px;
  color: transparent;
  background-color: rgba(239, 240, 241, 0.3);
  text-shadow: none; }
  switch:checked {
    background-color: #3daee9; }
  switch:backdrop {
    background-color: rgba(239, 240, 241, 0.3);
    text-shadow: none; }
    switch:backdrop:checked {
      background-color: #3daee9; }
  switch slider {
    min-width: 22px;
    min-height: 22px;
    border: 1px solid;
    border-radius: 11px;
    background-color: #31363b;
    border-color: #616569; }
  switch:hover slider {
    border-color: #3daee9; }
  switch:disabled slider {
    background-color: #2d3136; }
  switch:backdrop slider {
    background-color: #31363b; }
  switch:backdrop:disabled slider {
    background-color: #2d3136; }

/************
 * Toolbars *
 ************/
toolbar, .inline-toolbar, searchbar,
.location-bar {
  -GtkWidget-window-dragging: true;
  padding: 4px;
  background-color: #31363b; }

toolbar {
  padding: 4px 3px 3px 4px; }
  toolbar:backdrop {
    background-color: #31363b;
    box-shadow: none; }
  toolbar button {
    margin: 2px;
    padding: 3px; }
    toolbar button.image-button, toolbar button.text-button.image-button {
      padding: 3px; }
  toolbar separator {
    margin-left: 3px;
    margin-right: 3px; }
  toolbar entry {
    margin: 3px; }
  .osd toolbar {
    background-color: transparent; }
  toolbar.osd {
    padding: 13px;
    border: none;
    border-radius: 3px;
    background-color: #31363b; }
    toolbar.osd:backdrop {
      border-color: #616569;
      background-color: #31363b;
      box-shadow: none; }
    toolbar.osd.left, toolbar.osd.right, toolbar.osd.top, toolbar.osd.bottom {
      border-radius: 0; }

.inline-toolbar {
  border-width: 0px 0px 1px 0px;
  padding: 3px;
  border-radius: 0; }

searchbar,
.location-bar {
  border-width: 0px 0px 1px 0px;
  padding: 3px; }

.inline-toolbar, searchbar,
.location-bar {
  border-style: solid;
  border-color: #616569;
  text-shadow: none;
  background-color: #31363b; }

/************
 * Tooltips *
 ************/
tooltip {
  color: #eff0f1;
  padding: 4px;
  /* not working */
  border-radius: 3px;
  box-shadow: none;
  text-shadow: none; }
  tooltip.background {
    background-color: #31363b;
    background-clip: padding-box; }
  tooltip.window-frame.csd {
    background-color: transparent;
    box-shadow: none; }
  tooltip decoration {
    background-color: transparent; }

tooltip * {
  padding: 0px;
  background-color: transparent;
  color: #eff0f1; }

/**************
 * Tree Views *
 **************/
treeview.view {
  -GtkTreeView-grid-line-width: 0;
  -GtkTreeView-grid-line-pattern: '';
  -GtkTreeView-tree-line-width: 1;
  -GtkTreeView-tree-line-pattern: '';
  -GtkTreeView-expander-size: 16;
  border-left-color: #616569;
  border-top-color: transparent; }
  treeview.view:selected {
    border-radius: 0; }
  treeview.view:selected {
    background-color: #3daee9;
    border-left-color: #eff0f1;
    border-top-color: #eff0f1; }
  treeview.view:backdrop:selected {
    background-color: rgba(61, 174, 233, 0.5);
    border-left-color: #eff0f1;
    border-top-color: #eff0f1; }
  treeview.view:disabled {
    color: rgba(88, 92, 95, 0.35); }
    treeview.view:disabled:selected {
      color: rgba(216, 218, 221, 0.35); }
      treeview.view:disabled:selected:backdrop {
        color: rgba(216, 218, 221, 0.35); }
    treeview.view:disabled:backdrop {
      color: rgba(88, 92, 95, 0.35); }
  treeview.view.seperator {
    min-height: 2px;
    color: #616569; }
  treeview.view.separator:backdrop {
    color: #616569; }
  treeview.view:backdrop {
    border-left-color: #616569; }
  treeview.view:drop(active) {
    border-style: solid none;
    border-width: 1px;
    border-color: #3daee9; }
  treeview.view.expander {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    color: #eff0f1; }
    treeview.view.expander:dir(rtl) {
      -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
    treeview.view.expander:hover {
      color: #3daee9; }
    treeview.view.expander:selected {
      color: #eff0f1; }
    treeview.view.expander:checked {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
      treeview.view.expander:checked:selected {
        color: #eff0f1; }
      treeview.view.expander:checked:backdrop {
        color: #232629; }
    treeview.view.expander:backdrop {
      color: #232629; }
  treeview.view header button {
    color: #eff0f1;
    background-color: #31363b;
    text-shadow: none;
    box-shadow: none; }
    treeview.view header button:hover {
      color: #eff0f1;
      background-color: rgba(61, 174, 233, 0.5);
      box-shadow: none;
      transition: none; }
    treeview.view header button:active {
      color: #eff0f1;
      background-color: rgba(61, 174, 233, 0.5);
      transition: none; }
  treeview.view header button:last-child:backdrop, treeview.view header button:last-child {
    border-right-style: none; }
  treeview.view button.dnd:active, treeview.view button.dnd:selected, treeview.view button.dnd:hover, treeview.view button.dnd,
  treeview.view header.button.dnd:active,
  treeview.view header.button.dnd:selected,
  treeview.view header.button.dnd:hover,
  treeview.view header.button.dnd {
    padding: 0 6px;
    color: #eff0f1;
    background-image: none;
    background-color: #3daee9;
    border-style: none;
    border-radius: 0;
    box-shadow: none;
    text-shadow: none;
    transition: none; }

treeview.view header button, treeview.view header button:hover, treeview.view header button:active {
  padding: 6px;
  border-style: none solid solid none;
  border-radius: 0;
  background-image: none;
  border-color: #616569;
  text-shadow: none; }
  treeview.view header button:disabled {
    border-color: rgba(88, 92, 95, 0.35);
    color: rgba(216, 218, 221, 0.35);
    background-color: #2d3136;
    background-image: none; }
  treeview.view header button:backdrop {
    border-color: #616569;
    border-style: none solid solid none;
    color: #eff0f1;
    background-image: none;
    background-color: #31363b; }
    treeview.view header button:backdrop:disabled {
      border-color: rgba(88, 92, 95, 0.35);
      background-image: none;
      background-color: #2d3136;
      color: rgba(216, 218, 221, 0.35); }

/**********************
 * Window Decorations *
 *********************/
decoration {
  border-radius: 3px 3px 0 0;
  border-width: 0px;
  box-shadow: 0 2px 6px 1px rgba(0, 0, 0, 0.5);
  /* this is used for the resize cursor area */
  margin: 10px; }
  .maximized decoration, .fullscreen decoration, .tiled decoration {
    border-radius: 0; }
  .popup decoration {
    border-radius: 3px;
    box-shadow: 2px 2px 2px 1px rgba(0, 0, 0, 0.1); }
  .ssd decoration {
    box-shadow: 0 2px 6px 1px rgba(0, 0, 0, 0.1); }
  .csd decoration {
    border-radius: 3px; }
    .csd decoration.popup {
      box-shadow: 2px 2px 2px 1px rgba(0, 0, 0, 0.1); }
    .csd decoration.tooltip {
      box-shadow: none; }
    .csd decoration.message-dialog {
      box-shadow: 0 2px 6px 1px rgba(0, 0, 0, 0.5); }
  .solid-csd decoration {
    border-radius: 0;
    margin: 0;
    padding: 1px;
    border: none;
    background-color: #616569;
    box-shadow: none; }

headerbar.default-decoration button.titlebutton,
.titlebar.default-decoration button.titlebutton {
  padding: 6px 1px;
  min-height: 18px;
  min-width: 18px;
  margin: 0; }
headerbar button.titlebutton,
.titlebar button.titlebutton {
  padding: 6px; }
  headerbar button.titlebutton:hover, headerbar button.titlebutton:active, headerbar button.titlebutton:checked, headerbar button.titlebutton:backdrop, headerbar button.titlebutton:active:hover,
  .titlebar button.titlebutton:hover,
  .titlebar button.titlebutton:active,
  .titlebar button.titlebutton:checked,
  .titlebar button.titlebutton:backdrop,
  .titlebar button.titlebutton:active:hover {
    transition: none; }
  headerbar button.titlebutton.close,
  .titlebar button.titlebutton.close {
    padding: 6px 1px;
    color: transparent;
    border-image: none;
    box-shadow: none;
    background-position: center;
    background-repeat: no-repeat;
    background-image: -gtk-scaled(url("../assets/titlebutton-close.png"), url("../assets/titlebutton-close@2.png")); }
  headerbar button.titlebutton.close:hover,
  .titlebar button.titlebutton.close:hover {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-close-hover.png"), url("../assets/titlebutton-close-hover@2.png")); }
  headerbar button.titlebutton.close:active,
  .titlebar button.titlebutton.close:active {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-close-active.png"), url("../assets/titlebutton-close-active@2.png")); }
  headerbar button.titlebutton.close:backdrop,
  .titlebar button.titlebutton.close:backdrop {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-close-backdrop.png"), url("../assets/titlebutton-close-backdrop@2.png")); }
  headerbar button.titlebutton.maximize,
  .titlebar button.titlebutton.maximize {
    padding: 6px 1px;
    color: transparent;
    border-image: none;
    box-shadow: none;
    background-position: center;
    background-repeat: no-repeat;
    background-image: -gtk-scaled(url("../assets/titlebutton-maximize.png"), url("../assets/titlebutton-maximize@2.png")); }
  headerbar button.titlebutton.maximize:hover,
  .titlebar button.titlebutton.maximize:hover {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-maximize-hover.png"), url("../assets/titlebutton-maximize-hover@2.png")); }
  headerbar button.titlebutton.maximize:active,
  .titlebar button.titlebutton.maximize:active {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-maximize-active.png"), url("../assets/titlebutton-maximize-active@2.png")); }
  headerbar button.titlebutton.maximize:backdrop,
  .titlebar button.titlebutton.maximize:backdrop {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-maximize-backdrop.png"), url("../assets/titlebutton-maximize-backdrop@2.png")); }
  headerbar button.titlebutton.minimize,
  .titlebar button.titlebutton.minimize {
    padding: 6px 1px;
    color: transparent;
    border-image: none;
    box-shadow: none;
    background-position: center;
    background-repeat: no-repeat;
    background-image: -gtk-scaled(url("../assets/titlebutton-minimize.png"), url("../assets/titlebutton-minimize@2.png")); }
  headerbar button.titlebutton.minimize:hover,
  .titlebar button.titlebutton.minimize:hover {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-minimize-hover.png"), url("../assets/titlebutton-minimize-hover@2.png")); }
  headerbar button.titlebutton.minimize:active,
  .titlebar button.titlebutton.minimize:active {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-minimize-active.png"), url("../assets/titlebutton-minimize-active@2.png")); }
  headerbar button.titlebutton.minimize:backdrop,
  .titlebar button.titlebutton.minimize:backdrop {
    border-color: transparent;
    background-color: transparent;
    background-image: -gtk-scaled(url("../assets/titlebutton-minimize-backdrop.png"), url("../assets/titlebutton-minimize-backdrop@2.png")); }
.maximized headerbar button.titlebutton.maximize, .maximized
.titlebar button.titlebutton.maximize {
  padding: 6px 1px;
  color: transparent;
  border-image: none;
  box-shadow: none;
  background-position: center;
  background-repeat: no-repeat;
  background-image: -gtk-scaled(url("../assets/titlebutton-maximize-maximized.png"), url("../assets/titlebutton-maximize-maximized@2.png")); }
.maximized headerbar button.titlebutton.maximize:hover, .maximized
.titlebar button.titlebutton.maximize:hover {
  border-color: transparent;
  background-color: transparent;
  background-image: -gtk-scaled(url("../assets/titlebutton-maximize-maximized-hover.png"), url("../assets/titlebutton-maximize-maximized-hover@2.png")); }
.maximized headerbar button.titlebutton.maximize:active, .maximized
.titlebar button.titlebutton.maximize:active {
  border-color: transparent;
  background-color: transparent;
  background-image: -gtk-scaled(url("../assets/titlebutton-maximize-maximized-active.png"), url("../assets/titlebutton-maximize-maximized-active@2.png")); }
.maximized headerbar button.titlebutton.maximize:backdrop, .maximized
.titlebar button.titlebutton.maximize:backdrop {
  border-color: transparent;
  background-color: transparent;
  background-image: -gtk-scaled(url("../assets/titlebutton-maximize-maximized-backdrop.png"), url("../assets/titlebutton-maximize-maximized-backdrop@2.png")); }

headerbar.selection-mode button.titlebutton,
.titlebar.selection-mode button.titlebutton {
  text-shadow: none; }
  headerbar.selection-mode button.titlebutton:backdrop,
  .titlebar.selection-mode button.titlebutton:backdrop {
    -gtk-icon-shadow: none; }
